AdvanceOptions class

视频编码的高级选项。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

compressionPreference CompressionPreference?
视频编码的压缩偏好。详见 CompressionPreference 。
final
encodeAlpha bool?
当视频帧包含 Alpha 通道数据时,设置是否将 Alpha 数据编码并发送至远端: true :对 Alpha 数据进行编码发送。 false :(默认)不对 Alpha 数据进行编码发送。
final
encodingPreference EncodingPreference?
视频编码器偏好。详见 EncodingPreference 。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited