AdvancedConfigInfo class

Local Access Point 的高级选项。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
logUploadServer LogUploadServerInfo?
自定义的日志上传服务器。默认情况下,SDK 会将日志上传至声网日志服务器。你可以通过该参数修改日志上传的服务器。详见 LogUploadServerInfo 。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited