AgoraPipOptions class

声网画中画模式的配置选项。

自从 自 v4.6.2 版本新增。 该类提供平台特定的选项来配置 Android 和 iOS 平台的画中画行为。

Properties

aspectRatioX int?
画中画窗口的水平宽高比。
final
aspectRatioY int?
画中画窗口的垂直宽高比。
final
autoEnterEnabled bool?
是否自动进入画中画模式。
final
contentView int?
用于视频渲染的内容视图标识符。
getter/setter pair
contentViewLayout AgoraPipContentViewLayout?
画中画视频流的布局配置。
final
controlStyle int?
画中画窗口的控制样式。 可用样式: 0:显示所有系统控件(默认) 1:隐藏前进和后退按钮 2:隐藏播放/暂停按钮和进度条(推荐) 3:隐藏所有系统控件,包括关闭和恢复按钮 仅适用于 iOS 平台。
final
externalStateMonitorInterval int?
外部状态监控的间隔,单位为毫秒。
final
hashCode int
The hash code for this object.
no setterinherited
preferredContentHeight int?
画中画内容的首选高度。
final
preferredContentWidth int?
画中画内容的首选宽度。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
seamlessResizeEnabled bool?
是否启用画中画窗口的无缝调整大小。
final
sourceContentView int?
源内容视图标识符。
final
sourceRectHintBottom int?
源矩形提示的下坐标。
final
sourceRectHintLeft int?
源矩形提示的左坐标。
final
sourceRectHintRight int?
源矩形提示的右坐标。
final
sourceRectHintTop int?
源矩形提示的上坐标。
final
useExternalStateMonitor bool?
是否使用外部状态监控。
final
videoStreams List<AgoraPipVideoStream>?
视频转码配置。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited