AgoraPipState enum

表示画中画模式的当前状态。

自从 自 v4.6.2 版本新增。

Inheritance
Available extensions

Values

pipStateStarted → const AgoraPipState

画中画模式已成功启动。

pipStateStopped → const AgoraPipState

画中画模式已停止。

pipStateFailed → const AgoraPipState

画中画模式启动失败或遇到错误。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AgoraPipState>
A constant List of the values in this enum, in order of their declaration.