AgoraPipStateChangedObserver class

画中画状态改变的观测器。

自从 自 v4.6.2 版本新增。 实现此类以接收画中画状态转换和潜在错误的通知。

Properties

hashCode int
The hash code for this object.
no setterinherited
onPipStateChanged → void Function(AgoraPipState state, String? error)
画中画状态改变回调。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited