AgoraPipVideoStream class

画中画模式的视频流配置。

自从 自 v4.6.2 版本新增。 该类保存显示画中画窗口内视频流所需的连接和画布设置。

Properties

canvas VideoCanvas
用于渲染此视频流的画布配置,详见 VideoCanvas 。
final
connection RtcConnection
与此视频流关联的 RTC 连接。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited