AgoraRhythmPlayerConfig class

虚拟节拍器配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

beatsPerMeasure int?
每小节的拍数,取值范围为 1,9。默认值为 4,即每小节包含 1 个强拍和 3 个弱拍。
final
beatsPerMinute int?
节拍速度(拍/分钟),取值范围为 60,360。默认值为 60,即 1 分钟有 60 拍。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited