AgoraRtcException class

错误码及错误描述。

Implemented types

Properties

code int
错误码,详见 ErrorCodeType 。
final
hashCode int
The hash code for this object.
no setterinherited
message String?
错误描述。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited