AreaCode enum

访问区域,即 SDK 连接的服务器所在的区域。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

areaCodeCn → const AreaCode

中国大陆。

areaCodeNa → const AreaCode

北美区域。

areaCodeEu → const AreaCode

欧洲区域。

areaCodeAs → const AreaCode

除中国以外的亚洲区域。

areaCodeJp → const AreaCode

日本。

areaCodeIn → const AreaCode

印度。

areaCodeGlob → const AreaCode

全球。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AreaCode>
A constant List of the values in this enum, in order of their declaration.