AudioDeviceInfo class
AudioDeviceInfo 类,包含音频设备的 ID 和设备名称。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- deviceId → String?
-
设备 ID。
final
- deviceName → String?
-
设备名称。
final
- deviceTypeName → String?
-
音频设备类型,如:built-in、USB、HDMI 等。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited