AudioDeviceManager class abstract
音频设备管理方法。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enumeratePlaybackDevices(
) → Future< List< AudioDeviceInfo> > - 获取系统中所有的播放设备列表。
-
enumerateRecordingDevices(
) → Future< List< AudioDeviceInfo> > - 获取系统中所有的音频采集设备列表。
-
followSystemLoopbackDevice(
bool enable) → Future< void> - 设置声卡采集设备是否跟随系统默认的播放设备。
-
followSystemPlaybackDevice(
bool enable) → Future< void> - 设置 SDK 使用的音频播放设备跟随系统默认的音频播放设备。
-
followSystemRecordingDevice(
bool enable) → Future< void> - 设置 SDK 使用的音频采集设备跟随系统默认的音频采集设备。
-
getLoopbackDevice(
) → Future< String> - 获取当前的声卡采集设备。
-
getPlaybackDefaultDevice(
) → Future< AudioDeviceInfo> - 获取系统默认的音频播放设备。
-
getPlaybackDevice(
) → Future< String> - 获取当前音频播放设备。
-
getPlaybackDeviceInfo(
) → Future< AudioDeviceInfo> - 获取音频播放设备信息。
-
getPlaybackDeviceMute(
) → Future< bool> - 获取当前播放设备静音状态。
-
getPlaybackDeviceVolume(
) → Future< int> - 获取播放设备音量。
-
getRecordingDefaultDevice(
) → Future< AudioDeviceInfo> - 获取系统默认的音频采集设备。
-
getRecordingDevice(
) → Future< String> - 获取当前音频采集设备。
-
getRecordingDeviceInfo(
) → Future< AudioDeviceInfo> - 获取音频采集设备信息。
-
getRecordingDeviceMute(
) → Future< bool> - 获取当前音频采集设备静音状态。
-
getRecordingDeviceVolume(
) → Future< int> - 获取音频采集设备音量。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → Future< void> - 释放 AudioDeviceManager 对象占用的所有资源。
-
setLoopbackDevice(
String deviceId) → Future< void> - 指定声卡采集设备。
-
setPlaybackDevice(
String deviceId) → Future< void> - 指定播放设备。
-
setPlaybackDeviceMute(
bool mute) → Future< void> - 设置播放设备静音。
-
setPlaybackDeviceVolume(
int volume) → Future< void> - 设置播放设备音量。
-
setRecordingDevice(
String deviceId) → Future< void> - 指定音频采集设备。
-
setRecordingDeviceMute(
bool mute) → Future< void> - 设置当前音频采集设备静音。
-
setRecordingDeviceVolume(
int volume) → Future< void> - 设置音频采集设备音量。
-
startAudioDeviceLoopbackTest(
int indicationInterval) → Future< void> - 开始音频设备回路测试。
-
startPlaybackDeviceTest(
String testAudioFilePath) → Future< void> - 启动音频播放设备测试。
-
startRecordingDeviceTest(
int indicationInterval) → Future< void> - 启动音频采集设备测试。
-
stopAudioDeviceLoopbackTest(
) → Future< void> - 停止音频设备回路测试。
-
stopPlaybackDeviceTest(
) → Future< void> - 停止音频播放设备测试。
-
stopRecordingDeviceTest(
) → Future< void> - 停止音频采集设备测试。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited