AudioEffectPreset enum

预设的音效选项。

setAudioProfile profile 预设音效 profile roomAcousticsVirtualStereo roomAcoustics3dVoice roomAcousticsVirtualSurroundSound audioProfileMusicHighQualityStereo 或 audioProfileMusicStandardStereo 其他预设音效(除 audioEffectOff 以外) audioProfileMusicHighQuality 或 audioProfileMusicHighQualityStereo

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

audioEffectOff → const AudioEffectPreset

原声,即关闭人声音效。

roomAcousticsKtv → const AudioEffectPreset

KTV。

roomAcousticsVocalConcert → const AudioEffectPreset

演唱会。

roomAcousticsStudio → const AudioEffectPreset

录音棚。

roomAcousticsPhonograph → const AudioEffectPreset

留声机。

roomAcousticsVirtualStereo → const AudioEffectPreset

虚拟立体声,即 SDK 将单声道的音频渲染出双声道的音效。

roomAcousticsSpacial → const AudioEffectPreset

空旷。

roomAcousticsEthereal → const AudioEffectPreset

空灵。

roomAcoustics3dVoice → const AudioEffectPreset

3D 人声,即 SDK 将音频渲染出在用户周围环绕的效果。环绕周期默认为 10 秒。设置该音效后,你还可以调用 setAudioEffectParameters 修改环绕周期。 启用 3D 人声后,用户需要使用支持双声道的音频播放设备才能听到预期效果。

roomAcousticsVirtualSurroundSound → const AudioEffectPreset

虚拟环绕声,即 SDK 在双声道的基础上产生仿真的环绕声场,从而营造出具有环绕感的音效。 启用虚拟环绕声后,用户需要使用支持双声道的音频播放设备才能听到预期效果。

roomAcousticsChorus → const AudioEffectPreset

合唱。声网推荐你在合唱场景下使用,使人声更具空间立体感。

voiceChangerEffectUncle → const AudioEffectPreset

大叔。 建议用于处理男声,否则无法达到预期效果。

voiceChangerEffectOldman → const AudioEffectPreset

老年男性。 建议用于处理男声,否则无法达到预期效果。

voiceChangerEffectBoy → const AudioEffectPreset

男孩。 建议用于处理男声,否则无法达到预期效果。

voiceChangerEffectSister → const AudioEffectPreset

少女。 建议用于处理女声,否则无法达到预期效果。

voiceChangerEffectGirl → const AudioEffectPreset

女孩。 建议用于处理女声,否则无法达到预期效果。

voiceChangerEffectPigking → const AudioEffectPreset

猪八戒。

voiceChangerEffectHulk → const AudioEffectPreset

绿巨人。

styleTransformationRnb → const AudioEffectPreset

R&B。

styleTransformationPopular → const AudioEffectPreset

流行。

pitchCorrection → const AudioEffectPreset

电音,即 SDK 以主音音高为 C 的自然大调为基础修正音频的实际音高。设置该音效后,你还可以调用 setAudioEffectParameters 调整修音的基础调式和主音音高。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AudioEffectPreset>
A constant List of the values in this enum, in order of their declaration.