AudioEncodedFrameObserverConfig class

编码后音频的观测器设置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

encodingType AudioEncodingType?
音频编码类型。详见 AudioEncodingType 。
final
hashCode int
The hash code for this object.
no setterinherited
postionType AudioEncodedFrameObserverPosition?
音频编码内容。详见 AudioEncodedFrameObserverPosition 。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited