AudioEncodedFrameObserverPosition enum
音频编码内容。
- Inheritance
- Available extensions
- Annotations
-
- @JsonEnum.new(alwaysCreate: true)
Values
- audioEncodedFrameObserverPositionRecord → const AudioEncodedFrameObserverPosition
-
1: 仅编码本地用户的音频。
- audioEncodedFrameObserverPositionPlayback → const AudioEncodedFrameObserverPosition
-
2: 仅编码所有远端用户的音频。
- audioEncodedFrameObserverPositionMixed → const AudioEncodedFrameObserverPosition
-
3: 编码本地和所有远端用户混音后的音频。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AudioEncodedFrameObserverPosition> - A constant List of the values in this enum, in order of their declaration.