AudioFrame class

原始音频数据。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

avsyncType int?
保留参数。
final
buffer Uint8List?
声音数据缓存区(如果是立体声,数据是交叉存储的)。 缓存区数据大小 buffer = samples × channels × bytesPerSample 。
final
bytesPerSample → BytesPerSample?
每个采样点的字节数。对于 PCM 来说,一般使用 16 bit,即两个字节。
final
channels int?
声道数量(如果是立体声,数据是交叉的)。 1: 单声道 2: 双声道
final
hashCode int
The hash code for this object.
no setterinherited
renderTimeMs int?
外部音频帧的渲染时间戳。 你可以使用该时间戳还原音频帧顺序;在有视频的场景中(包含使用外部视频源的场景),该参数可以用于实现音视频同步。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
samplesPerChannel int?
每个声道的采样点数。
final
samplesPerSec int?
每声道每秒的采样点数。
final
type AudioFrameType?
音频帧类型,详见 AudioFrameType 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited