AudioFrameObserverBase class
音频观测器。
你可以调用 registerAudioFrameObserver 注册或取消注册 AudioFrameObserverBase 音频观测器。
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onEarMonitoringAudioFrame → void Function(AudioFrame audioFrame)?
-
获得耳返的原始音频数据。
final
- onMixedAudioFrame → void Function(String channelId, AudioFrame audioFrame)?
-
获取采集和播放音频混音后的数据。
final
- onPlaybackAudioFrame → void Function(String channelId, AudioFrame audioFrame)?
-
获得播放的原始音频数据。
final
- onRecordAudioFrame → void Function(String channelId, AudioFrame audioFrame)?
-
获得采集的原始音频数据。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited