AudioMixingDualMonoMode enum

声道模式。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

audioMixingDualMonoAuto → const AudioMixingDualMonoMode

0:原始模式。

audioMixingDualMonoL → const AudioMixingDualMonoMode

1:左声道模式。该模式用左声道的音频替换右声道的音频,即用户只能听到左声道的音频。

audioMixingDualMonoR → const AudioMixingDualMonoMode

2:右声道模式。该模式用右声道的音频替换左声道的音频,即用户只能听到右声道的音频。

audioMixingDualMonoMix → const AudioMixingDualMonoMode

3:混合模式。该模式将左右声道的数据叠加,即用户能同时听到左声道和右声道的音频。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AudioMixingDualMonoMode>
A constant List of the values in this enum, in order of their declaration.