AudioRoute enum

音频路由的类型。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

routeDefault → const AudioRoute

-1: 使用默认的音频路由。

routeHeadset → const AudioRoute

0: 音频路由为带麦克风的耳机。

routeEarpiece → const AudioRoute

1: 音频路由为听筒。

routeHeadsetnomic → const AudioRoute

2: 音频路由为不带麦克风的耳机。

routeSpeakerphone → const AudioRoute

3: 音频路由为设备自带的扬声器。

routeLoudspeaker → const AudioRoute

4: 音频路由为外接的扬声器。(仅适用于 iOS 和 macOS)

routeBluetoothDeviceHfp → const AudioRoute

@nodoc

routeUsb → const AudioRoute

6: 音频路由为 USB 外围设备。(仅适用于 macOS)

routeHdmi → const AudioRoute

7: 音频路由为 HDMI 外围设备。(仅适用于 macOS)

routeDisplayport → const AudioRoute

8: 音频路由为 DisplayPort 外围设备。(仅适用于 macOS)

routeAirplay → const AudioRoute

9: 音频路由为 Apple AirPlay。(仅适用于 macOS)

routeBluetoothDeviceA2dp → const AudioRoute

@nodoc

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AudioRoute>
A constant List of the values in this enum, in order of their declaration.