BackgroundBlurDegree enum

自定义背景图的虚化程度。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

blurDegreeLow → const BackgroundBlurDegree

1: 自定义背景图的虚化程度为低。用户差不多能看清背景。

blurDegreeMedium → const BackgroundBlurDegree

2: 自定义背景图的虚化程度为中。用户较难看清背景。

blurDegreeHigh → const BackgroundBlurDegree

3:(默认)自定义背景图的虚化程度为高。用户很难看清背景。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<BackgroundBlurDegree>
A constant List of the values in this enum, in order of their declaration.