BeautyOptions class

美颜选项。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
lighteningContrastLevel LighteningContrastLevel?
对比度,常与 lighteningLevel 搭配使用。取值越大,明暗对比程度越大。详见 LighteningContrastLevel 。
final
lighteningLevel double?
美白程度,取值范围为 0.0,1.0,其中 0.0 表示原始亮度,默认值为 0.0。取值越大,美白程度越大。
final
rednessLevel double?
红润度,取值范围为 0.0,1.0,其中 0.0 表示原始红润度,默认值为 0.0。取值越大,红润程度越大。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sharpnessLevel double?
锐化程度,取值范围为 0.0,1.0,其中 0.0 表示原始锐度,默认值为 0.0。取值越大,锐化程度越大。
final
smoothnessLevel double?
磨皮程度,取值范围为 0.0,1.0,其中 0.0 表示原始磨皮程度,默认值为 0.0。取值越大,磨皮程度越大。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited