CacheStatistics class

缓存文件的统计数据。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

cacheSize int?
本次播放的媒体文件已缓存的数据大小,单位为字节。
final
downloadSize int?
本次播放已下载的媒体文件大小,单位为字节。
final
fileSize int?
本次播放的媒体文件的大小,单位为字节。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited