CameraCapturerConfiguration class

摄像头采集配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

cameraDirection CameraDirection?
(可选)摄像头方向。详见 CameraDirection 。 该参数仅适用于 Android 和 iOS 平台。
final
cameraFocalLengthType CameraFocalLengthType?
(可选)摄像头的焦距类型。详见 CameraFocalLengthType 。 该参数仅适用于 Android 和 iOS。 如需设置摄像头的焦距类型,仅支持通过 cameraDirection 指定摄像头,不支持通过 cameraId 进行指定。 部分 iOS 设备的后置摄像头为多个摄像头组成的融合镜头,如双摄(广角和超广角)或三摄(广角、超广角和长焦),对于这种具备超广角能力的融合镜头,你可以通过以下任意一种方式实现超广角的采集效果: 方式一:将该参数设置为 cameraFocalLengthUltraWide (2)(超广角镜头)。 方式二:将该参数设置为 cameraFocalLengthDefault (0)(标准镜头),然后调用 setCameraZoomFactor 将相机缩放比例设置为小于 1.0 的数值,最小可以设置为 0.5。 区别为方式一的超广角大小不可调节,方式二支持自由调节相机的缩放比例。
final
cameraId String?
(可选)摄像头 ID。默认为前置摄像头对应的摄像头 ID。你可以通过 Android 原生系统 API 获取摄像头 ID,详见 Camera.open()CameraManager.getCameraIdList()。 该参数仅适用于 Android。 该参数和 cameraDirection 均用于指定摄像头,二者为互斥关系,你可以按需选用其中之一,具体区别如下: 通过 cameraDirection 指定摄像头的方式更为简便。你只需指定摄像头的方向(前置或后置),无需指定具体的摄像头 ID,SDK 会通过系统 API 去检索和确定实际的摄像头 ID。 通过 cameraId 则可以更精确地指定某个特定的摄像头。对于多摄像头的设备, cameraDirection 无法识别或访问全部可用摄像头,这种情况建议使用 cameraId 直接指定你想要的摄像头 ID。
final
deviceId String?
(可选)摄像头的 ID。最大长度为 MaxDeviceIdLengthType 。 该参数仅适用于 Windows 和 macOS。
final
followEncodeDimensionRatio bool?
(可选)是否跟随 setVideoEncoderConfiguration 中设置的视频宽高比: true :(默认) 跟随。SDK 会将采集到的视频按照已设置的视频宽高比进行裁剪,会同步改变本地预览画面、 onCaptureVideoFrame 和 onPreEncodeVideoFrame 中的视频画面。 false :不跟随。SDK不改变采集到的视频帧宽高比。
final
format VideoFormat?
(可选)视频帧格式。详见 VideoFormat 。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited