ChannelMediaRelayError enum

跨频道媒体流转发出错的错误码。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

relayOk → const ChannelMediaRelayError

0: 一切正常。

relayErrorServerErrorResponse → const ChannelMediaRelayError

1: 服务器回应出错。

relayErrorServerNoResponse → const ChannelMediaRelayError

2: 服务器无回应。 该错误可能是网络状况不佳导致的。如果在发起跨频道连麦时报告该错误,你可以稍后重试;如果在跨频道连麦过程中报告该错误,你可以调用 leaveChannel 方法离开频道。 该错误也可能是由于当前的 App ID 未开启跨频道连麦导致的。你可以联系技术支持申请开通跨频道连麦。

relayErrorNoResourceAvailable → const ChannelMediaRelayError

3: SDK 无法获取服务,可能是因为服务器资源有限导致。

relayErrorFailedJoinSrc → const ChannelMediaRelayError

4: 发起跨频道转发媒体流请求失败。

relayErrorFailedJoinDest → const ChannelMediaRelayError

5: 接受跨频道转发媒体流请求失败。

relayErrorFailedPacketReceivedFromSrc → const ChannelMediaRelayError

6: 服务器接收跨频道转发媒体流失败。

relayErrorFailedPacketSentToDest → const ChannelMediaRelayError

7: 服务器发送跨频道转发媒体流失败。

relayErrorServerConnectionLost → const ChannelMediaRelayError

8: SDK 因网络质量不佳与服务器断开。你可以调用 leaveChannel 方法离开当前频道。

relayErrorInternalError → const ChannelMediaRelayError

9: 服务器内部出错。

relayErrorSrcTokenExpired → const ChannelMediaRelayError

10: 源频道的 Token 已过期。

relayErrorDestTokenExpired → const ChannelMediaRelayError

11: 目标频道的 Token 已过期。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ChannelMediaRelayError>
A constant List of the values in this enum, in order of their declaration.