ClientRoleChangeFailedReason enum

切换用户角色失败的原因。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

clientRoleChangeFailedTooManyBroadcasters → const ClientRoleChangeFailedReason

1: 频道内主播人数达到上限。 该枚举仅在开启 128 人功能后报告。主播人数的上限根据开启 128 人功能时实际配置的人数而定。

clientRoleChangeFailedNotAuthorized → const ClientRoleChangeFailedReason

2: 请求被服务端拒绝。建议提示用户重新尝试切换用户角色。

clientRoleChangeFailedRequestTimeOut → const ClientRoleChangeFailedReason

3: 请求超时。建议提示用户检查网络连接状况后重新尝试切换用户角色。 废弃:该枚举值自 v4.4.0 起废弃,不建议使用。

clientRoleChangeFailedConnectionFailed → const ClientRoleChangeFailedReason

4: 网络连接断开。可根据 onConnectionStateChanged 报告的 reason ,排查网络连接失败的具体原因。 废弃:该枚举值自 v4.4.0 起废弃,不建议使用。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ClientRoleChangeFailedReason>
A constant List of the values in this enum, in order of their declaration.