CodecCapInfo class

SDK 支持的编解码能力信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

codecCapMask int?
SDK 编解码类型的 bit mask。详见 CodecCapMask 。
final
codecLevels CodecCapLevels?
SDK 支持的编解码能力等级。详见 CodecCapLevels 。
final
codecType VideoCodecType?
视频编解码类型。详见 VideoCodecType 。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited