CodecCapLevels class

编解码能力等级。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
hwDecodingLevel VideoCodecCapabilityLevel?
硬件解码能力等级,表示设备能够对不同品质视频进行硬件解码的能力。详见 VideoCodecCapabilityLevel 。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
swDecodingLevel VideoCodecCapabilityLevel?
软件解码能力等级,表示设备能够对不同品质视频进行软件解码的能力。详见 VideoCodecCapabilityLevel 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited