ContentInspectConfig class

本地截图上传配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

extraInfo String?
附加信息,最大长度为 1024 字节。 SDK 会将附加信息和截图一起上传至声网服务器;截图完成后,声网服务器会将附加信息随回调通知一起发送给你的服务器。
final
hashCode int
The hash code for this object.
no setterinherited
moduleCount int?
功能模块数,即配置的 ContentInspectModule 实例的数量,必须与 modules 中配置的实例个数一致。最大值为 32。
final
modules List<ContentInspectModule>?
功能模块。详见 ContentInspectModule 。 最多支持配置 32 个 ContentInspectModule 实例, MAX_CONTENT_INSPECT_MODULE_COUNT 的取值范围为 1,32 中的整数。 一个功能模块最多只能配置一个实例。目前仅支持截图上传功能。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverConfig String?
(可选)云市场视频审核相关服务端配置,该参数仅在 ContentInspectModule 中的 type 设置为 contentInspectImageModeration 时生效。如需使用,请联系技术支持
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited