ContentInspectModule class

ContentInspectModule 结构体,用于配置本地截图上传的频率。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
interval int?
本地截图上传的间隔,单位为秒,取值必须大于 0。默认值为 0,表示不进行截图上传。推荐值为 10 秒,你也可以根据业务需求自行调整。
final
position VideoModulePosition?
视频观察器的位置。详见 VideoModulePosition 。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ContentInspectType?
功能模块的类型。详见 ContentInspectType 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited