DirectCdnStreamingMediaOptions class

主播端的媒体选项。

废弃 自 v4.6.0 版本废弃。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

customVideoTrackId int?
调用 createCustomVideoTrack 方法返回的视频轨道 ID。默认值为 0。
final
hashCode int
The hash code for this object.
no setterinherited
publishCameraTrack bool?
设置是否发布摄像头采集的视频。 true : 发布摄像头采集的视频。 false :(默认)不发布摄像头采集的视频。
final
publishCustomAudioTrack bool?
设置是否发布自定义采集的音频。 true : 发布自定义采集的音频。 false :(默认)不发布自定义采集的音频。
final
publishCustomVideoTrack bool?
设置是否发布自定义采集的视频。 true : 发布自定义采集的视频。 false :(默认)不发布自定义采集的视频。
final
publishMicrophoneTrack bool?
设置是否发布麦克风采集的音频。 true : 发布麦克风采集的音频。 false :(默认)不发布麦克风采集的音频。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited