DirectCdnStreamingReason enum

CDN 推流状态改变的原因。

废弃 自 v4.6.0 版本废弃。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

directCdnStreamingReasonOk → const DirectCdnStreamingReason

0:推流状态正常。

directCdnStreamingReasonFailed → const DirectCdnStreamingReason

1:一般性错误,没有明确原因。你可以尝试重新推流。

directCdnStreamingReasonAudioPublication → const DirectCdnStreamingReason

2:音频推流出错。例如,本地音频采集设备未正常工作、被其他进程占用或没有使用权限。

directCdnStreamingReasonVideoPublication → const DirectCdnStreamingReason

3:视频推流出错。例如,本地视频采集设备未正常工作、被其他进程占用或没有使用权限。

directCdnStreamingReasonNetConnect → const DirectCdnStreamingReason

4:连接 CDN 失败。

directCdnStreamingReasonBadName → const DirectCdnStreamingReason

5:URL 已用于推流。请使用新的 URL。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DirectCdnStreamingReason>
A constant List of the values in this enum, in order of their declaration.