DirectCdnStreamingState enum

当前 CDN 推流状态。

废弃 自 v4.6.0 版本废弃。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

directCdnStreamingStateIdle → const DirectCdnStreamingState

0:初始状态,即推流尚未开始。

directCdnStreamingStateRunning → const DirectCdnStreamingState

1:正在推流中。当你调用 startDirectCdnStreaming 成功推流时,SDK 会返回该值。

directCdnStreamingStateStopped → const DirectCdnStreamingState

2:推流已正常结束。当你调用 stopDirectCdnStreaming 主动停止推流时,SDK 会返回该值。

directCdnStreamingStateFailed → const DirectCdnStreamingState

3:推流失败。你可以通过 onDirectCdnStreamingStateChanged 回调报告的信息排查问题,然后重新推流。

directCdnStreamingStateRecovering → const DirectCdnStreamingState

4:尝试重新连接声网服务器和 CDN。最多尝试重连 10 次,如仍未成功恢复连接,则推流状态变为 directCdnStreamingStateFailed。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DirectCdnStreamingState>
A constant List of the values in this enum, in order of their declaration.