DirectCdnStreamingStats class

当前 CDN 推流的统计数据。

废弃 自 v4.6.0 版本废弃。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

audioBitrate int?
当前音频码率(bps)。
final
fps int?
当前视频帧率(fps)。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoBitrate int?
当前视频码率(bps)。
final
videoHeight int?
视频的高度(px)。
final
videoWidth int?
视频的宽度(px)。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited