EncodedAudioFrameInfo class

编码后音频的信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

advancedSettings → EncodedAudioFrameAdvancedSettings?
该功能暂不支持。
final
captureTimeMs int?
采集外部编码视频帧的 Unix 时间戳 (ms)。
final
codec AudioCodecType?
音频编码规格: AudioCodecType 。
final
hashCode int
The hash code for this object.
no setterinherited
numberOfChannels int?
声道数。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRateHz int?
音频采样率 (Hz)。
final
samplesPerChannel int?
每个声道的音频采样数。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited