EncodedVideoFrameInfo class

外部编码视频帧的信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

captureTimeMs int?
采集外部编码视频帧的 Unix 时间戳 (ms)。
final
codecType VideoCodecType?
视频编码类型,详见 VideoCodecType 。默认值为 videoCodecH264 (2) 。
final
framesPerSecond int?
每秒的视频帧数。 当该参数不为 0 时,你可以用它计算外部编码视频帧的 Unix 时间戳。
final
frameType VideoFrameType?
视频帧的类型,详见 VideoFrameType 。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
视频帧的高度 (px)。
final
rotation VideoOrientation?
视频帧的旋转信息,详见 VideoOrientation 。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamType VideoStreamType?
视频流类型。详见 VideoStreamType 。
final
trackId int?
预留参数。
final
width int?
视频帧的宽度 (px)。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited