EncodingPreference enum
视频编码器偏好。
Values
- preferAuto → const EncodingPreference
-
-1:自适应偏好。SDK 根据平台、设备类型等因素自动选择最优的编码类型进行编码。
- preferSoftware → const EncodingPreference
-
0:软件编码偏好。SDK 优先使用软件编码器进行视频编码。
- preferHardware → const EncodingPreference
-
1:硬件编码偏好。SDK 优先使用硬件编码器进行视频编码。当设备不支持硬件编码时,SDK 会自动使用软件编码,并通过 onLocalVideoStats 回调中的 hwEncoderAccelerating 报告当前使用的视频编码器类型。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
EncodingPreference> - A constant List of the values in this enum, in order of their declaration.