EncryptionConfig class

配置内置加密模式和密钥。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

datastreamEncryptionEnabled bool?
是否开启数据流加密: true :开启数据流加密。 false :(默认)关闭数据流加密。
final
encryptionKdfSalt Uint8List?
盐,长度为 32 字节。建议你在服务端使用 OpenSSL 生成盐。 只有在 aes128Gcm2 或 aes256Gcm2 加密模式下,该参数才生效。此时,需确保填入该参数的值不全为 0 。
final
encryptionKey String?
内置加密密钥,字符串类型,长度无限制。建议使用 32 字节的密钥。 如果未指定该参数或将该参数设置为 NULL ,则无法启用内置加密,且 SDK 会返回错误码 -2 。
final
encryptionMode EncryptionMode?
内置加密模式。详见 EncryptionMode 。建议使用 aes128Gcm2 或 aes256Gcm2 加密模式。这两种模式支持使用盐,安全性更高。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited