EncryptionMode enum

内置加密模式。

建议使用 aes128Gcm2 或 aes256Gcm2 加密模式。这两种模式支持使用盐,安全性更高。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

aes128Xts → const EncryptionMode

1: 128 位 AES 加密,XTS 模式。

aes128Ecb → const EncryptionMode

2: 128 位 AES 加密,ECB 模式。

aes256Xts → const EncryptionMode

3: 256 位 AES 加密,XTS 模式。

sm4128Ecb → const EncryptionMode

4: 128 位 SM4 加密,ECB 模式。

aes128Gcm → const EncryptionMode

5: 128 位 AES 加密,GCM 模式。

aes256Gcm → const EncryptionMode

6: 256 位 AES 加密,GCM 模式。

aes128Gcm2 → const EncryptionMode

7:(默认)128 位 AES 加密,GCM 模式。该加密模式需要设置盐( encryptionKdfSalt )。

aes256Gcm2 → const EncryptionMode

8: 256 位 AES 加密,GCM 模式。该加密模式需要设置盐( encryptionKdfSalt )。

modeEnd → const EncryptionMode

枚举值边界。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EncryptionMode>
A constant List of the values in this enum, in order of their declaration.