FaceInfoObserver class

人脸信息观测器。

你可以调用 registerFaceInfoObserver 注册 FaceInfoObserver 观测器。

Properties

hashCode int
The hash code for this object.
no setterinherited
onFaceInfo → void Function(String outFaceInfo)?
报告已获取语音驱动插件处理后的人脸信息。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited