FocalLengthInfo class

摄像头支持的焦距信息,包含摄像头的方向以及焦距类型。

仅适用于 Android 和 iOS。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

cameraDirection int?
摄像头方向。详见 CameraDirection 。
final
focalLengthType CameraFocalLengthType?
焦距类型。详见 CameraFocalLengthType 。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited