FrameRate enum

视频帧率。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

frameRateFps1 → const FrameRate

1: 1 fps。

frameRateFps7 → const FrameRate

7: 7 fps。

frameRateFps10 → const FrameRate

10: 10 fps。

frameRateFps15 → const FrameRate

15: 15 fps。

frameRateFps24 → const FrameRate

24: 24 fps。

frameRateFps30 → const FrameRate

30: 30 fps。

frameRateFps60 → const FrameRate

60: 60 fps。 仅适用于 Windows 和 macOS 平台。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FrameRate>
A constant List of the values in this enum, in order of their declaration.