ImageTrackOptions class

垫片图片的设置选项。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

fps int?
视频帧率,取值范围为 1,30。默认值为 1。
final
hashCode int
The hash code for this object.
no setterinherited
imageUrl String?
垫片图片的 URL,目前支持 JPEG、JPG、PNG、GIF 格式的图片。支持从本地绝对路径或相对路径添加垫片图片。 在 Android 平台上,不支持从 /assets/ 中添加垫片图片。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited