LastmileProbeConfig class

Last mile 网络探测配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

expectedDownlinkBitrate int?
用户期望的最高接收码率,单位为 bps,范围为 100000,5000000
final
expectedUplinkBitrate int?
用户期望的最高发送码率,单位为 bps,范围为 100000,5000000。建议参考 setVideoEncoderConfiguration 中的码率值设置该参数的值。
final
hashCode int
The hash code for this object.
no setterinherited
是否探测下行网络: true : 探测下行网络。 false : 不探测下行网络。
final
是否探测上行网络。有些用户,如直播频道中的普通观众,不需要进行网络探测: true : 探测上行网络。 false : 不探测上行网络。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited