LastmileProbeOneWayResult class
上行或下行 Last mile 网络质量探测结果。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- availableBandwidth → int?
-
可用网络带宽预估 (bps)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jitter → int?
-
网络抖动 (ms)。
final
- packetLossRate → int?
-
丢包率。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited