LastmileProbeResult class

上下行 Last mile 网络质量探测结果。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

downlinkReport LastmileProbeOneWayResult?
下行网络质量报告。详见 LastmileProbeOneWayResult 。
final
hashCode int
The hash code for this object.
no setterinherited
rtt int?
往返时延 (ms)。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state LastmileProbeResultState?
Last mile 质量探测结果的状态。详见: LastmileProbeResultState 。
final
uplinkReport LastmileProbeOneWayResult?
上行网络质量报告。详见 LastmileProbeOneWayResult 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited