LastmileProbeResultState enum

Last mile 质量探测结果的状态。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

lastmileProbeResultComplete → const LastmileProbeResultState

1: 表示本次 last mile 质量探测的结果是完整的。

lastmileProbeResultIncompleteNoBwe → const LastmileProbeResultState

2: 表示本次 last mile 质量探测未进行带宽预测,因此结果不完整。一个可能的原因是测试资源暂时受限。

lastmileProbeResultUnavailable → const LastmileProbeResultState

3: 未进行 last mile 质量探测。一个可能的原因是网络连接中断。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LastmileProbeResultState>
A constant List of the values in this enum, in order of their declaration.