LeaveChannelOptions class

离开频道的选项。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopAllEffect bool?
离开频道时,是否停止播放音效: true :(默认)停止播放音效。 false : 不停止播放音效。
final
stopAudioMixing bool?
离开频道时,是否停止播放音乐文件及混音: true :(默认)停止播放音乐文件及混音。 false : 不停止播放音乐文件及混音。
final
stopMicrophoneRecording bool?
离开频道时,是否停止麦克风采集: true :(默认)停止麦克风采集。 false : 不停止麦克风采集。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited