LocalAudioMixerConfiguration class

本地音频合流配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

audioInputStreams List<MixedAudioStream>?
在本地进行合流的音频源。详见 MixedAudioStream 。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamCount int?
在本地进行合流的音频流数量。
final
syncWithLocalMic bool?
合流后的音频流是否使用本地麦克风采集的音频帧时间戳: true :(默认)使用本地麦克风采集的音频帧时间戳。如果要所有本地采集的音频流保持同步,你可以将参数设置为该值。 false :不使用本地麦克风采集的音频帧时间戳,SDK 会采用合流的音频帧被构建时的时间戳。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited