LocalAudioStats class

本地音频统计数据。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

aecEstimatedDelay int?
回声消除延迟 (ms),即回声消除 (Acoustic Echo Cancellation, AEC) 模块测算出音频在本地播放前与被本地采集后的信号延迟。
final
audioDeviceDelay int?
播放或录制音频时,音频设备模块的延迟 (ms)。
final
earMonitorDelay int?
耳返延迟 (ms),即声音从麦克风输入到耳机输出的延迟。
final
hashCode int
The hash code for this object.
no setterinherited
internalCodec int?
内部的 payload 类型。
final
numChannels int?
声道数。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sentBitrate int?
发送本地音频的码率平均值,单位为 Kbps。
final
sentSampleRate int?
发送本地音频的采样率,单位为 Hz。
final
txPacketLossRate int?
弱网对抗前本端到声网边缘服务器的丢包率 (%)。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited