LocalProxyMode enum

与声网私有媒体服务器的连接模式。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

connectivityFirst → const LocalProxyMode

0:SDK 优先尝试连接指定的声网私有媒体服务器;如果无法连接到指定的声网私有媒体服务器,则连接声网 SD-RTN™。

localOnly → const LocalProxyMode

1:SDK 只尝试连接指定的声网私有媒体服务器。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LocalProxyMode>
A constant List of the values in this enum, in order of their declaration.