LocalSpatialAudioEngine class abstract
该类通过 SDK 计算用户坐标,实现空间音频。
该类继承自 BaseSpatialAudioEngine 。调用该类下其他 API 前,你需要调用 initialize 方法初始化该类。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
clearRemotePositions(
) → Future< void> - 删除所有远端用户的空间位置信息。
-
initialize(
) → Future< void> - 初始化 LocalSpatialAudioEngine 。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeRemotePosition(
int uid) → Future< void> - 删除指定远端用户的空间位置信息。
-
setRemoteAudioAttenuation(
{required int uid, required double attenuation, required bool forceSet}) → Future< void> - 设置指定用户的声音衰减效果。
-
toString(
) → String -
A string representation of this object.
inherited
-
updateRemotePosition(
{required int uid, required RemoteVoicePositionInfo posInfo}) → Future< void> - 更新远端用户的空间位置信息。
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited