LocalTranscoderConfiguration class

本地合图的配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
streamCount int?
参与本地合图的视频流的数量。
final
videoInputStreams List<TranscodingVideoStream>?
参与本地合图的视频流。详见 TranscodingVideoStream 。
final
videoOutputConfiguration VideoEncoderConfiguration?
本地合图后,合图视频的编码配置。详见 VideoEncoderConfiguration 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited