LogUploadServerInfo class

日志服务器的配置信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverDomain String?
日志服务器的域名。
final
serverHttps bool?
日志服务器是否使用 HTTPS 协议: true : 使用 HTTPS 协议。 false : 使用 HTTP 协议。
final
serverPath String?
日志在服务器上的存储路径。
final
serverPort int?
日志服务器的端口。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited