LowLightEnhanceLevel enum

暗光增强等级。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

lowLightEnhanceLevelHighQuality → const LowLightEnhanceLevel

0:(默认)优先画质的暗光增强,会处理视频图像的亮度、细节、噪声,消耗的性能适中,处理速度适中,综合画质最优。

lowLightEnhanceLevelFast → const LowLightEnhanceLevel

1:优先性能的暗光增强,会处理视频图像的亮度、细节,消耗的性能较少,处理速度较快。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LowLightEnhanceLevel>
A constant List of the values in this enum, in order of their declaration.