MediaPlayerCacheManager class abstract

该类提供管理媒体播放器中缓存媒体文件的方法。

Constructors

MediaPlayerCacheManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

enableAutoRemoveCache(bool enable) Future<void>
设置是否开启自动清除缓存文件功能。
getCacheDir(int length) Future<String>
获取缓存文件的储存路径。
getCacheFileCount() Future<int>
获取当前已缓存的媒体文件的总数量。
getMaxCacheFileCount() Future<int>
获取所设置的缓存文件数量上限。
getMaxCacheFileSize() Future<int>
获取所设置的缓存文件总缓存的上限。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeAllCaches() Future<void>
删除媒体播放器中所有已缓存的媒体文件。
removeCacheByUri(String uri) Future<void>
删除指定的已缓存媒体文件。
removeOldCache() Future<void>
删除媒体播放器中近期最少使用的一个缓存媒体文件。
setCacheDir(String path) Future<void>
设置待缓存的媒体文件的储存路径。
setMaxCacheFileCount(int count) Future<void>
设置缓存媒体文件数量的上限。
setMaxCacheFileSize(int cacheSize) Future<void>
设置缓存媒体文件的总缓存大小的上限。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited