MediaPlayerSourceObserver class

提供媒体播放器的回调。

Properties

hashCode int
The hash code for this object.
no setterinherited
onAudioVolumeIndication → void Function(int volume)?
媒体播放器音量提示回调。
final
onMetaData → void Function(Uint8List data, int length)?
报告已获取媒体附属信息。
final
onPlayBufferUpdated → void Function(int playCachedBuffer)?
报告当前缓冲数据能播放的时间。
final
onPlayerCacheStats → void Function(CacheStatistics stats)?
报告当前缓存中的媒体资源的相关信息。
final
onPlayerEvent → void Function(MediaPlayerEvent eventCode, int elapsedTime, String message)?
报告播放器的事件。
final
onPlayerInfoUpdated → void Function(PlayerUpdatedInfo info)?
媒体播放器相关信息发生改变回调。
final
onPlayerPlaybackStats → void Function(PlayerPlaybackStats stats)?
报告当前播放的媒体资源的相关信息。
final
onPlayerSourceStateChanged → void Function(MediaPlayerState state, MediaPlayerReason reason)?
报告播放器状态改变。
final
onPlayerSrcInfoChanged → void Function(SrcInfo from, SrcInfo to)?
媒体资源视频码率变化回调。
final
onPositionChanged → void Function(int positionMs, int timestampMs)?
报告当前媒体资源的播放进度。
final
onPreloadEvent → void Function(String src, PlayerPreloadEvent event)?
报告预加载媒体资源的事件。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited