MediaPlayerState enum

播放器的状态。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

playerStateIdle → const MediaPlayerState

0: 默认状态。播放器会在你打开媒体文件之前和结束播放之后返回该状态码。

playerStateOpening → const MediaPlayerState

1: 正在打开媒体文件。

playerStateOpenCompleted → const MediaPlayerState

2: 成功打开媒体文件。

playerStatePlaying → const MediaPlayerState

3: 正在播放。

playerStatePaused → const MediaPlayerState

4: 暂停播放。

playerStatePlaybackCompleted → const MediaPlayerState

5: 播放完毕。

playerStatePlaybackAllLoopsCompleted → const MediaPlayerState

6: 循环播放已结束。

playerStateStopped → const MediaPlayerState

7: 播放已停止。

playerStatePausingInternal → const MediaPlayerState

@nodoc

playerStateStoppingInternal → const MediaPlayerState

@nodoc

playerStateSeekingInternal → const MediaPlayerState

@nodoc

playerStateGettingInternal → const MediaPlayerState

@nodoc

playerStateNoneInternal → const MediaPlayerState

@nodoc

playerStateDoNothingInternal → const MediaPlayerState

@nodoc

playerStateSetTrackInternal → const MediaPlayerState

@nodoc

playerStateFailed → const MediaPlayerState

100: 播放失败。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MediaPlayerState>
A constant List of the values in this enum, in order of their declaration.