MediaRecorderConfiguration class

音视频流录制配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

channelNum int?
录制音频的声道数: 1: 单声道 2: 双声道 该参数仅在 调用 createMediaRecorder 且将 RecorderStreamInfo 中的 type 设置为 preview 时需要传入。
final
containerFormat MediaRecorderContainerFormat?
录制文件的格式。详见 MediaRecorderContainerFormat 。
final
fps int?
录制视频的帧率,最高值不超过 30,如: 5、10、15、24、30 等。 该参数仅在 调用 createMediaRecorder 且将 RecorderStreamInfo 中的 type 设置为 preview 时需要传入。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
录制视频的高度 (px),宽 × 高的最大值不超过 3840 × 2160。 该参数仅在 调用 createMediaRecorder 且将 RecorderStreamInfo 中的 type 设置为 preview 时需要传入。
final
maxDurationMs int?
最大录制时长,单位为毫秒,默认值为 120000。
final
recorderInfoUpdateInterval int?
录制信息更新间隔,单位为毫秒,取值范围为 1000,10000。SDK 会根据该值的设置触发 onRecorderInfoUpdated 回调,报告更新后的录制信息。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sampleRate int?
录制音频的采样率 (Hz),可设置为 16000,32000,44100 或 48000。 该参数仅在 调用 createMediaRecorder 且将 RecorderStreamInfo 中的 type 设置为 preview 时需要传入。
final
storagePath String?
请确保你指定的路径存在并且可写。 录制文件在本地保存的绝对路径,需精确到文件名及格式。例如: Windows: C:\Users<user_name>\AppData\Local\Agora<process_name>\example.mp4 iOS: /App Sandbox/Library/Caches/example.mp4 macOS: /Library/Logs/example.mp4 Android: /storage/emulated/0/Android/data/
final
streamType MediaRecorderStreamType?
录制内容。详见 MediaRecorderStreamType 。
final
videoSourceType VideoSourceType?
录制视频源的类型。详见 VideoSourceType 。 该参数仅在 调用 createMediaRecorder 且将 RecorderStreamInfo 中的 type 设置为 preview 时需要传入。
final
width int?
录制视频的宽度 (px),宽 × 高的最大值不应超过 3840 × 2160。 该参数仅在 调用 createMediaRecorder 且将 RecorderStreamInfo 中的 type 设置为 preview 时需要传入。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited