Metadata class

媒体附属信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

buffer Uint8List?
接收到的 Metadata 的缓存地址。
final
channelId String?
频道名称。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
接收到的或发送的 Metadata 的缓存大小。
final
timeStampMs int?
发送 Metadata 的时间戳,单位为毫秒。
final
uid int?
用户 ID。 对于接收者:发送该 Metadata 的远端用户的 ID。 对于发送者:请忽略。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited