MusicCacheInfo class

缓存的音乐资源的相关信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
songCode int?
音乐资源的编号,用于标识音乐资源。
final
status MusicCacheStatusType?
音乐资源的缓存状态,详见 MusicCacheStatusType 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited