MusicChartCollection class abstract
音乐榜单的详细信息。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
get(
int index) → Future< MusicChartInfo> - 获取音乐榜单的详细信息。
-
getCount(
) → Future< int> - 获取本次请求的音乐榜单数量。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited