MusicCollection class abstract

音乐资源列表的详细信息。

Constructors

MusicCollection()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getCount() int
获取本次请求的音乐数量。
getMusic(int index) Music
获取当前页面列表中音乐资源的详细信息。
getPage() int
获取音乐资源列表当前页的页码。
getPageSize() int
获取 SDK 实际返回的音乐资源数量。
getTotal() int
获取列表内音乐资源的总数量。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited