MusicContentCenterEventHandler class

MusicContentCenterEventHandler 接口类,用于 SDK 向客户端发送音乐内容中心事件通知。

Properties

hashCode int
The hash code for this object.
no setterinherited
onLyricResult → void Function(String requestId, int songCode, String lyricUrl, MusicContentCenterStateReason reason)?
歌词下载地址回调。
final
onMusicChartsResult → void Function(String requestId, List<MusicChartInfo> result, MusicContentCenterStateReason reason)?
获取音乐榜单回调。
final
onMusicCollectionResult → void Function(String requestId, MusicCollection result, MusicContentCenterStateReason reason)?
获取音乐资源列表回调。
final
onPreLoadEvent → void Function(String requestId, int songCode, int percent, String lyricUrl, PreloadState state, MusicContentCenterStateReason reason)?
报告预加载音乐资源的事件。
final
onSongSimpleInfoResult → void Function(String requestId, int songCode, String simpleInfo, MusicContentCenterStateReason reason)?
音乐资源的详细信息回调。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited