MusicContentCenterStateReason enum

音乐内容中心的请求状态码。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

kMusicContentCenterReasonOk → const MusicContentCenterStateReason

0:请求成功。

kMusicContentCenterReasonError → const MusicContentCenterStateReason

1:一般错误,无明确归因。

kMusicContentCenterReasonGateway → const MusicContentCenterStateReason

2:网关异常。可能的原因有: 当前使用的 Token 已过期。请重新生成 Token。 传入的 Token 无效。请确保你使用的是 RTM Token。 网络错误。请检查你的网络。

kMusicContentCenterReasonPermissionAndResource → const MusicContentCenterStateReason

3:权限错误或音乐资源不存在。请确保你的项目已开通声网音乐内容中心权限,请联系技术支持

kMusicContentCenterReasonInternalDataParse → const MusicContentCenterStateReason

4:内部数据解析错误。请联系技术支持

kMusicContentCenterReasonMusicLoading → const MusicContentCenterStateReason

5:音乐资源加载时出错。请联系技术支持

kMusicContentCenterReasonMusicDecryption → const MusicContentCenterStateReason

6:音乐资源解密时出错。请联系技术支持

kMusicContentCenterReasonHttpInternalError → const MusicContentCenterStateReason

7:HTTP 内部出现错误。请稍后重试。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MusicContentCenterStateReason>
A constant List of the values in this enum, in order of their declaration.