PathStats class

用于获取特定网络路径的统计数据。

自从 自 v4.6.2 版本新增。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxKBitRate int?
该路径的接收码率,单位为 Kbps。
final
txKBitRate int?
该路径的传输码率,单位为 Kbps。
final
type MultipathType?
网络路径的类型。详见 MultipathType 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited