PlayerPlaybackStats class

当前播放的媒体资源的相关信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

audioBitrateInKbps int?
音频码率,单位为 kbps。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBitrateInKbps int?
媒体流的总码率,单位为 kbps。
final
videoBitrateInKbps int?
视频码率,单位为 kbps。
final
videoFps int?
视频帧率,单位为 fps。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited