PreloadState enum

音乐资源的加载状态。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

kPreloadStateCompleted → const PreloadState

0:音乐资源加载完成。

kPreloadStateFailed → const PreloadState

1:音乐资源加载失败。

kPreloadStatePreloading → const PreloadState

2:音乐资源正在加载中。

kPreloadStateRemoved → const PreloadState

3:缓存的音乐资源已被移除。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<PreloadState>
A constant List of the values in this enum, in order of their declaration.