RecorderReasonCode enum
录制状态出错的原因。
Values
- recorderReasonNone → const RecorderReasonCode
-
0: 一切正常。
- recorderReasonWriteFailed → const RecorderReasonCode
-
1: 录制文件写入失败。
- recorderReasonNoStream → const RecorderReasonCode
-
2: 没有可录制的音视频流或者录制的音视频流中断超过 5 秒。
- recorderReasonOverMaxDuration → const RecorderReasonCode
-
3: 录制时长超出上限。
- recorderReasonConfigChanged → const RecorderReasonCode
-
4: 录制配置改变。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RecorderReasonCode> - A constant List of the values in this enum, in order of their declaration.