RecorderState enum
当前的录制状态。
Values
- recorderStateError → const RecorderState
-
-1: 音视频流录制出错,错误原因详见 RecorderReasonCode 。
- recorderStateStart → const RecorderState
-
2: 音视频流录制开始。
- recorderStateStop → const RecorderState
-
3: 音视频流录制停止。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RecorderState> - A constant List of the values in this enum, in order of their declaration.