Rectangle class

目标区域相对于整个屏幕或窗口的位置,如不填,则表示整个屏幕或窗口。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
height int?
目标区域的高度。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
目标区域的宽度。
final
x int?
左上角的横向偏移。
final
y int?
左上角的纵向偏移。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited