RemoteAudioStats class
远端用户的音频统计数据。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- audioLossRate → int?
-
统计周期内的远端音频流的丢帧率 (%)。
final
- e2eDelay → int?
-
端到端音频延时(毫秒),即自远端用户音频采集起,至本地用户开始播放音频的总时长。
final
- frozenRate → int?
-
音频卡顿的累计时长占音频总有效时长的百分比 (%)。音频有效时长是指远端用户加入频道后音频未被停止发送或禁用的时长。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- jitterBufferDelay → int?
-
音频接收端到网络抖动缓冲的网络延迟(毫秒)。 当接收端为观众且 ClientRoleOptions 的 audienceLatencyLevel 为 1 时,该参数不生效。
final
- mosValue → int?
-
统计周期内,声网实时音频 MOS(平均主观意见分)评估方法对接收到的远端音频流的质量评分。返回值范围为
0,500。返回值除以 100 即可得到 MOS 分数,范围为0,5分,分数越高,音频质量越好。 MOS 分数 音质感受 大于 4 分 音频质量佳,清晰流畅。 3.5 - 4 分 音频质量较好,偶有音质损伤,但依然清晰。 3 - 3.5 分 音频质量一般,偶有卡顿,不是非常流畅,需要一点注意力才能听清。 2.5 - 3 分 音频质量较差,卡顿频繁,需要集中精力才能听清。 2 - 2.5 分 音频质量很差,偶有杂音,部分语义丢失,难以交流。 小于 2 分 音频质量非常差,杂音频现,大量语义丢失,完全无法交流。final - networkTransportDelay → int?
-
音频发送端到接收端的网络延迟(毫秒)。
final
- numChannels → int?
-
声道数。
final
- publishDuration → int?
-
远端音频流的累计发布时长(毫秒)。
final
- qoeQuality → int?
-
接收远端音频时,本地用户的主观体验质量。
final
- quality → int?
-
远端用户发送的音频流质量。详见 QualityType 。
final
- qualityChangedReason → int?
-
接收远端音频时,本地用户主观体验质量较差的原因。详见 ExperiencePoorReason 。
final
- receivedBitrate → int?
-
接收到的远端音频流在统计周期内的平均码率(Kbps)。
final
- receivedSampleRate → int?
-
统计周期内接收到的远端音频流的采样率。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalActiveTime → int?
-
远端用户在音频通话开始到本次回调之间的有效时长(毫秒)。
有效时长是指去除了远端用户进入静音状态的总时长。
final
- totalFrozenTime → int?
-
远端用户在加入频道后发生音频卡顿的累计时长(毫秒)。通话过程中,音频丢帧率达到 4% 即记为一次音频卡顿。
final
- uid → int?
-
远端用户的用户 ID。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited