RemoteVideoState enum

远端视频流状态。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

remoteVideoStateStopped → const RemoteVideoState

0: 远端视频默认初始状态。在 remoteVideoStateReasonLocalMuted 、 remoteVideoStateReasonRemoteMuted 或 remoteVideoStateReasonRemoteOffline 的情况下,会报告该状态。

remoteVideoStateStarting → const RemoteVideoState

1: 本地用户已接收远端视频首包。

remoteVideoStateDecoding → const RemoteVideoState

2: 远端视频流正在解码,正常播放。在 remoteVideoStateReasonNetworkRecovery 、 remoteVideoStateReasonLocalUnmuted 、 remoteVideoStateReasonRemoteUnmuted 或 remoteVideoStateReasonAudioFallbackRecovery 的情况下,会报告该状态。

remoteVideoStateFrozen → const RemoteVideoState

3: 远端视频流卡顿。在 remoteVideoStateReasonNetworkCongestion 或 remoteVideoStateReasonAudioFallback 的情况下,会报告该状态。

remoteVideoStateFailed → const RemoteVideoState

4: 远端视频流播放失败。在 remoteVideoStateReasonInternal 的情况下,会报告该状态。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RemoteVideoState>
A constant List of the values in this enum, in order of their declaration.