RemoteVideoStateReason enum

远端视频流状态切换原因。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

remoteVideoStateReasonInternal → const RemoteVideoStateReason

0: 视频状态发生改变时,会报告该原因。

remoteVideoStateReasonNetworkCongestion → const RemoteVideoStateReason

1: 网络阻塞。

remoteVideoStateReasonNetworkRecovery → const RemoteVideoStateReason

2: 网络恢复正常。

remoteVideoStateReasonLocalMuted → const RemoteVideoStateReason

3: 本地用户停止接收远端视频流或本地用户禁用视频模块。

remoteVideoStateReasonLocalUnmuted → const RemoteVideoStateReason

4: 本地用户恢复接收远端视频流或本地用户启动视频模块。

remoteVideoStateReasonRemoteMuted → const RemoteVideoStateReason

5: 远端用户停止发送视频流或远端用户禁用视频模块。

remoteVideoStateReasonRemoteUnmuted → const RemoteVideoStateReason

6: 远端用户恢复发送视频流或远端用户启用视频模块。

remoteVideoStateReasonRemoteOffline → const RemoteVideoStateReason

7: 远端用户离开频道。

remoteVideoStateReasonAudioFallback → const RemoteVideoStateReason

8: 弱网情况下,远端音视频流回退为音频流。

remoteVideoStateReasonAudioFallbackRecovery → const RemoteVideoStateReason

9: 网络情况改善时,远端音频流恢复为音视频流。

remoteVideoStateReasonVideoStreamTypeChangeToLow → const RemoteVideoStateReason

@nodoc

remoteVideoStateReasonVideoStreamTypeChangeToHigh → const RemoteVideoStateReason

@nodoc

remoteVideoStateReasonSdkInBackground → const RemoteVideoStateReason

12:(仅适用于 iOS) 远端用户的 App 已切换到后台。

remoteVideoStateReasonCodecNotSupport → const RemoteVideoStateReason

13:本地的视频解码器不支持对收到的远端视频流进行解码。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RemoteVideoStateReason>
A constant List of the values in this enum, in order of their declaration.