RemoteVideoStats class

远端视频流的统计信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

avSyncTimeMs int?
音频超前视频的时间 (ms)。 如果为负值,则代表音频落后于视频。
final
decoderOutputFrameRate int?
远端视频解码器的输出帧率,单位为 fps。
final
delay int?
延时(毫秒)。 弃用:在有音画同步机制的音视频场景中,你可以参考 RemoteAudioStats 里的 networkTransportDelay 和 jitterBufferDelay 成员的值,了解视频的延迟数据。
final
e2eDelay int?
端到端视频延时(毫秒)。即,自远端用户视频采集起,至本地用户接收并渲染视频的总时长。
final
frameLossRate int?
远端视频丢包率(%)。
final
frozenRate int?
远端用户在加入频道后发生视频卡顿的累计时长占视频总有效时长的百分比 (%)。视频有效时长是指远端用户加入频道后视频未被停止发送或禁用的时长。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
视频流高(像素)。
final
mosValue int?
在统计周期内远端音频流的质量。该质量由声网实时音频 MOS(主观意见评分)测量方法确定。返回值范围为 0, 500,除以 100 后为 MOS 分数,范围为 0 到 5,分数越高表示音频质量越好。声网实时音频 MOS 评分对应的主观音质感受如下: 大于 4 分,音频质量佳,清晰流畅。 3.5 - 4 分,音频质量较好,偶有音质损伤,但依然清晰。 3 - 3.5 分,音频质量一般,偶有卡顿,不是非常流畅,需要一点注意力才能听清。 2.5 - 3 分,音频质量较差,卡顿频繁,需要集中精力才能听清。 2 - 2.5 分,音频质量很差,偶有杂音,部分语义丢失,难以交流。 小于 2 分,音频质量非常差,杂音频现,大量语义丢失,完全无法交流。
final
packetLossRate int?
远端视频在使用抗丢包技术之后的丢包率(%)。
final
publishDuration int?
远端视频流的累计发布时长(毫秒)。
final
receivedBitrate int?
(上次统计后)接收到的码率(Kbps)。
final
rendererOutputFrameRate int?
远端视频渲染器的输出帧率,单位为 fps。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxStreamType VideoStreamType?
视频流类型,大流或小流。详见 VideoStreamType 。
final
totalActiveTime int?
视频有效时长(毫秒)。 视频总有效时长是远端用户或主播加入频道后,既没有停止发送视频流,也没有禁用视频模块的通话时长。
final
totalFrozenTime int?
远端用户在加入频道后发生视频卡顿的累计时长(ms)。通话过程中,视频帧率设置不低于 5 fps 时,连续渲染的两帧视频之间间隔超过 500 ms,则记为一次视频卡顿。
final
uid int?
用户 ID,指定是哪个用户的视频流。
final
width int?
视频流宽(像素)。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited