RhythmPlayerReason enum

虚拟节拍器错误信息。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

rhythmPlayerReasonOk → const RhythmPlayerReason

0:正常播放节拍音频文件,没有错误。

rhythmPlayerReasonFailed → const RhythmPlayerReason

1:一般性错误,没有明确原因。

rhythmPlayerReasonCanNotOpen → const RhythmPlayerReason

801:打开节拍音频文件出错。

rhythmPlayerReasonCanNotPlay → const RhythmPlayerReason

802:播放节拍音频文件出错。

rhythmPlayerReasonFileOverDurationLimit → const RhythmPlayerReason

803:节拍音频文件时长超出限制。最大时长为 1.2 秒。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RhythmPlayerReason>
A constant List of the values in this enum, in order of their declaration.