RtcConnection class

包含连接信息的类。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

channelId String?
频道名。
final
hashCode int
The hash code for this object.
no setterinherited
localUid int?
本地用户 ID。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited