RtcImage class

图像属性。

用于设置直播视频的水印和背景图片的属性。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

alpha double?
水印或背景图片的透明度。取值范围为 0.0,1.0: 0.0: 完全透明。 1.0:(默认)完全不透明。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
图片在视频画面上的高度 (px)。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
直播视频上图片的 HTTP/HTTPS 地址。字符长度不得超过 1024 字节。
final
width int?
图片在视频画面上的宽度 (px)。
final
x int?
图片在视频画面上的 x 坐标 (px),以输出视频画面的左上角为原点。
final
y int?
图片在视频画面上的 y 坐标 (px),以输出视频画面的左上角为原点。
final
zOrder int?
水印或背景图的图层编号。使用水印数组添加单张或多张水印时,必须向 zOrder 传值,取值范围为 1,255,否则 SDK 会报错。其余情况, zOrder 可选传值,取值范围为 0,255,0 为默认值。0 代表图层的最下层,255 代表图层的最上层。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited