RtcStats class

通话相关的统计信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

connectTimeMs int?
从开始建立连接到成功连接的时间(毫秒)。如报告 0,则表示无效。
final
cpuAppUsage double?
当前 App 的 CPU 使用率 (%)。 onLeaveChannel 回调中报告的 cpuAppUsage 恒为 0。 自 Android 8.1 起,因系统限制,你可能无法通过该属性获取 CPU 使用率。
final
cpuTotalUsage double?
当前系统的 CPU 使用率 (%)。 对于 Windows 平台,在多核环境中,该成员指多核 CPU 的平均使用率。 计算方式为 (100 - 任务管理中显示的系统空闲进程 CPU)/100。 onLeaveChannel 回调中报告的 cpuTotalUsage 恒为 0。
final
duration int?
本地用户通话时长(秒),累计值。
final
gatewayRtt int?
客户端到本地路由器的往返时延 (ms)。 该属性默认在 iOS 14 之前的设备上开启,在 iOS 14 及之后的设备上关闭。
final
hashCode int
The hash code for this object.
no setterinherited
lastmileDelay int?
客户端-接入服务器延时 (毫秒)。
final
memoryAppUsageInKbytes int?
当前 App 的内存大小 (KB)。 该值仅作参考。受系统限制可能无法获取。
final
memoryAppUsageRatio double?
当前 App 的内存占比 (%)。 该值仅作参考。受系统限制可能无法获取。
final
memoryTotalUsageRatio double?
当前系统的内存占比 (%)。 该值仅作参考。受系统限制可能无法获取。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
rxAudioBytes int?
接收音频字节数 (bytes),累计值。
final
rxAudioKBitRate int?
音频接收码率 (Kbps)。
final
rxBytes int?
接收字节数 (bytes)。
final
rxKBitRate int?
接收码率 (Kbps)。
final
rxPacketLossRate int?
使用抗丢包技术前,服务器下行发送到客户端丢包率 (%)。
final
rxVideoBytes int?
接收视频字节数 (bytes),累计值。
final
rxVideoKBitRate int?
视频接收码率 (Kbps)。
final
txAudioBytes int?
发送音频字节数 (bytes),累计值。
final
txAudioKBitRate int?
音频包的发送码率 (Kbps)。
final
txBytes int?
发送字节数 (bytes)。
final
txKBitRate int?
发送码率 (Kbps)。
final
txPacketLossRate int?
使用抗丢包技术前,客户端上行发送到服务器丢包率 (%)。
final
txVideoBytes int?
发送视频字节数 (bytes),累计值。
final
txVideoKBitRate int?
视频发送码率 (Kbps)。
final
userCount int?
当前频道内的用户人数。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited