ScreenCaptureConfiguration class

屏幕采集配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

displayId int?
(仅适用于 macOS 平台)屏幕的 display ID。 请仅在 Mac 设备上采集屏幕时使用该参数。
final
hashCode int
The hash code for this object.
no setterinherited
isCaptureWindow bool?
是否采集屏幕上的窗口: true :采集窗口。 false :(默认)采集屏幕,不采集窗口。
final
params ScreenCaptureParameters?
(仅适用于 Windows 和 macOS 平台)屏幕共享流的编码参数配置。详见 ScreenCaptureParameters 。
final
regionRect Rectangle?
(仅适用于 Windows 和 macOS 平台)待共享区域相对于整个屏幕的位置。详见 Rectangle 。如不填,则表示共享整个屏幕。如果设置的共享区域超出了屏幕的边界,则只共享屏幕内的内容。 如果将 Rectangle 中的 width 或 height 设为 0 ,则共享整个屏幕。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
screenRect Rectangle?
(仅适用于 Windows 平台)待共享的屏幕相对于虚拟屏的位置。 请仅在 Windows 设备上采集屏幕时使用该参数。
final
windowId int?
(仅适用于 Windows 和 macOS 平台)窗口 ID。 请仅在采集窗口时使用该参数。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited