ScreenCaptureParameters2 class

屏幕共享的参数配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

audioParams ScreenAudioParameters?
共享屏幕流的音频配置。详见 ScreenAudioParameters 。 该参数仅在 captureAudio 为 true 时生效。
final
captureAudio bool?
受系统限制,采集系统音频仅适用于 Android API 级别为 29 及以上,即 Android 10 及以上。 为提高屏幕共享时采集系统音频的成功率,请确保你已调用 setAudioScenario 方法并设置音频场景为 audioScenarioGameStreaming 。 屏幕共享时是否采集系统音频: true : 采集系统音频。 false : (默认)不采集系统音频。
final
captureVideo bool?
受系统限制,采集屏幕仅适用于 Android API 级别为 21 及以上,即 Android 5 及以上。 屏幕共享时是否采集屏幕: true :(默认)采集屏幕。 false : 不采集屏幕。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoParams ScreenVideoParameters?
共享屏幕流的视频编码配置。详见 ScreenVideoParameters 。 该参数仅在 captureVideo 为 true 时生效。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited