ScreenVideoParameters class

共享屏幕流的视频编码配置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

bitrate int?
视频编码码率 (Kbps)。
final
contentHint VideoContentHint?
屏幕共享视频的内容类型。
final
dimensions VideoDimensions?
视频编码的分辨率。默认值为 1280 × 720。
final
frameRate int?
视频编码帧率 (fps)。默认值为 15。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited