SimulcastStreamMode enum
发送视频流的模式。
Values
- autoSimulcastStream → const SimulcastStreamMode
-
-1:默认不发送小流,直至收到接收端发起的订阅小流申请时,开始自动发送小流。
- disableSimulcastStream → const SimulcastStreamMode
-
0:始终不发送小流。
- enableSimulcastStream → const SimulcastStreamMode
-
1:始终发送小流。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SimulcastStreamMode> - A constant List of the values in this enum, in order of their declaration.