SrcInfo class

媒体资源播放时的视频码率相关信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

bitrateInKbps int?
媒体资源播放时的视频码率(Kbps)。
final
hashCode int
The hash code for this object.
no setterinherited
name String?
媒体资源的名字。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited