StreamPublishState enum

发布状态。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

pubStateIdle → const StreamPublishState

0: 加入频道后的初始发布状态。

pubStateNoPublished → const StreamPublishState

1: 发布失败。可能是因为: 本地用户调用 muteLocalAudioStream (true) 或 muteLocalVideoStream (true) 停止发送本地媒体流。 本地用户调用 disableAudio 或 disableVideo 关闭本地音频或视频模块。 本地用户调用 enableLocalAudio (false) 或 enableLocalVideo (false) 关闭本地音频或视频采集。 本地用户角色为观众。

pubStatePublishing → const StreamPublishState

2: 正在发布。

pubStatePublished → const StreamPublishState

3: 发布成功。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StreamPublishState>
A constant List of the values in this enum, in order of their declaration.