StreamSubscribeState enum

订阅状态。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

subStateIdle → const StreamSubscribeState

0: 加入频道后的初始订阅状态。

subStateNoSubscribed → const StreamSubscribeState

1: 订阅失败。可能是因为: 远端用户: 调用 muteLocalAudioStream (true) 或 muteLocalVideoStream (true) 停止发送本地媒体流。 调用 disableAudio 或 disableVideo 关闭本地音频或视频模块。 调用 enableLocalAudio (false) 或 enableLocalVideo (false) 关闭本地音频或视频采集。 用户角色为观众。 本地用户调用以下方法停止接收远端媒体流: 调用 muteRemoteAudioStream (true)、 muteAllRemoteAudioStreams (true) 停止接收远端音频流。 调用 muteRemoteVideoStream (true)、 muteAllRemoteVideoStreams (true) 停止接收远端视频流。

subStateSubscribing → const StreamSubscribeState

2: 正在订阅。

subStateSubscribed → const StreamSubscribeState

3: 收到了远端流,订阅成功。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StreamSubscribeState>
A constant List of the values in this enum, in order of their declaration.