TranscodingVideoStream class

参与本地合图的视频流。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

alpha double?
参与本地合图的视频的透明度。取值范围为 0.0,1.0。 0.0 表示透明度为完全透明,1.0 表示透明度为完全不透明。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
参与本地合图的视频的高度 (px)。
final
imageUrl String?
请仅在参与本地合图的视频源类型为图片时,使用该参数。 本地图片的路径。 示例路径: Android: /storage/emulated/0/Pictures/image.png iOS: /var/mobile/Containers/Data/Application/
final
mediaPlayerId int?
(可选)媒体播放器 ID。当你将 sourceType 设置为 videoSourceMediaPlayer 时,需要设置该参数。
final
mirror bool?
该参数仅对视频源类型为摄像头的视频生效。 是否对参与本地合图的的视频进行镜像: true : 将参与本地合图的视频进行镜像。 false : (默认值)不将参与本地合图的视频进行镜像。
final
remoteUserUid int?
远端用户 ID。 请仅在参与本地合图的视频源类型为 videoSourceRemote 时,使用该参数。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceType VideoSourceType?
参与本地合图的视频源类型。详见 VideoSourceType 。
final
width int?
参与本地合图的视频的宽度 (px)。
final
x int?
参与本地合图的视频的左上角相对于合图画布左上角(原点)的横向位移。
final
y int?
参与本地合图的视频的左上角相对于合图画布左上角(原点)的纵向位移。
final
zOrder int?
参与本地合图的视频所属的图层的编号。取值范围为 0,100。 0:(默认值)图层在最下层。 100: 图层在最上层。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited