VideoContentHint enum

屏幕共享的内容类型。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

contentHintNone → const VideoContentHint

(默认)无指定的内容类型。

contentHintMotion → const VideoContentHint

内容类型为动画。当共享的内容是视频、电影或视频游戏时,推荐选择该内容类型。

contentHintDetails → const VideoContentHint

内容类型为细节。当共享的内容是图片或文字时,推荐选择该内容类型。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoContentHint>
A constant List of the values in this enum, in order of their declaration.