VideoEffectAction enum
对视频特效节点执行的操作类型。
自从 自 v4.6.2 版本新增。
Values
- save → const VideoEffectAction
-
(1):保存当前视频特效的参数。
- reset → const VideoEffectAction
-
(2):将视频特效重置为默认参数。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoEffectAction> - A constant List of the values in this enum, in order of their declaration.