VideoEffectNodeId enum
视频特效节点类型。
自从 自 v4.6.2 版本新增。
Values
- beauty → const VideoEffectNodeId
-
(1):美颜特效节点。
- styleMakeup → const VideoEffectNodeId
-
(2):风格妆特效节点。
- filter → const VideoEffectNodeId
-
(4):滤镜特效节点。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoEffectNodeId> - A constant List of the values in this enum, in order of their declaration.