VideoEffectObject class abstract

用于管理和配置视频特效,例如美颜、风格妆容和滤镜。

自从 自 v4.6.2 版本新增。

Constructors

VideoEffectObject()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addOrUpdateVideoEffect({required int nodeId, required String templateName}) Future<void>
添加或更新指定视频特效节点和模板的特效。
getVideoEffectBoolParam({required String option, required String key}) Future<bool>
获取视频特效中的布尔参数。
getVideoEffectFloatParam({required String option, required String key}) Future<double>
获取视频特效中指定 float 类型参数的值。
getVideoEffectIntParam({required String option, required String key}) Future<int>
获取视频特效中的整数类型参数。
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performVideoEffectAction({required int nodeId, required VideoEffectAction actionId}) Future<void>
对指定的视频特效节点执行操作。
removeVideoEffect(int nodeId) Future<void>
移除指定节点 ID 的视频特效。
setVideoEffectBoolParam({required String option, required String key, required bool param}) Future<void>
设置视频特效的布尔参数。
setVideoEffectFloatParam({required String option, required String key, required double param}) Future<void>
设置视频特效的浮点参数。
setVideoEffectIntParam({required String option, required String key, required int param}) Future<void>
setVideoEffectIntParam :设置视频特效的整数参数。
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited