VideoEncodedFrameObserver class

用于接收编码后的视频图像的类。

Properties

hashCode int
The hash code for this object.
no setterinherited
onEncodedVideoFrameReceived → void Function(String channelId, int uid, Uint8List imageBuffer, int length, EncodedVideoFrameInfo videoEncodedFrameInfo)?
报告接收端已收到远端发送的待解码视频帧。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited