VideoEncoderConfiguration class
视频编码器的配置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- advanceOptions → AdvanceOptions?
-
视频编码的高级选项。详见 AdvanceOptions 。
final
- bitrate → int?
-
视频编码码率,单位为 Kbps。该参数无需设置,保留默认值 standardBitrate 即可,SDK 会根据你设定的视频分辨率和帧率自动匹配最合适的码率。有关视频分辨率和帧率的对应关系,详见视频属性。
standardBitrate (0): (默认) 标准码率模式。
compatibleBitrate (-1): 适配码率模式。一般情况下,声网建议你不要使用该值。
final
- codecType → VideoCodecType?
-
视频编码类型,详见 VideoCodecType 。
final
- degradationPreference → DegradationPreference?
-
带宽受限时,视频编码降级偏好。详见 DegradationPreference 。 当该参数设置为 maintainFramerate (1) 或者 maintainBalanced (2) 时,需要同时将 orientationMode 设置为 orientationModeAdaptive (0),否则设置不生效。
final
- dimensions → VideoDimensions?
-
视频编码的分辨率 (px),详见 VideoDimensions 。该参数用于衡量编码质量,以长 × 宽表示,默认值为 960 × 540。用户可以自行设置分辨率。
final
- frameRate → int?
-
视频编码的帧率(fps),默认值为 15。详见 FrameRate 。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- minBitrate → int?
-
最低编码码率,单位为 Kbps。
SDK 会根据网络状况自动调整视频编码码率。将参数设为高于默认值可强制视频编码器输出高质量图片,但在网络状况不佳情况下可能导致网络丢包并影响视频播放的流畅度造成卡顿。因此如非对画质有特殊需求,声网建议不要修改该参数的值。 该参数仅适用于直播场景。
final
- mirrorMode → VideoMirrorModeType?
-
发送编码视频时是否开启镜像模式,只影响远端用户看到的视频画面。详见 VideoMirrorModeType 。 默认关闭镜像模式。
final
- orientationMode → OrientationMode?
-
视频编码的方向模式,详见 OrientationMode 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited