VideoFormat class

视频帧格式。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

fps int?
视频帧的帧率。默认值为 15。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
视频帧的高度(px)。默认值为 540.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
视频帧的宽度(px)。默认值为 960。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited