VideoLayout class

某一路合图子视频流的布局信息。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

channelId String?
合图子视频流所属的频道名。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
合图子视频流的高度 (px)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strUid String?
预留参数。
final
uid int?
发布该合图子视频流的用户 ID。
final
videoState int?
合图子视频流在合图画布上的状态。 0:正常。该视频流已被渲染到合图画布。 1:占位图。该视频流无视频画面,在合图画布中显示为占位符。 2:黑色图片。该视频流被黑色图片替代。
final
width int?
合图子视频流的宽度 (px)。
final
x int?
合图子视频在合图画布上的 x 坐标 (px)。即合图子视频的左上角相对于合图画布左上角(原点)的横向位移。
final
y int?
合图子视频在合图画布上的 y 坐标 (px)。即合图子视频的左上角相对于合图画布左上角(原点)的纵向位移。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited