VideoOrientation enum

视频顺时针旋转信息。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

videoOrientation0 → const VideoOrientation

0:(默认)顺时针旋转 0 度。

videoOrientation90 → const VideoOrientation

90: 顺时针旋转 90 度。

videoOrientation180 → const VideoOrientation

180: 顺时针旋转 180 度。

videoOrientation270 → const VideoOrientation

270: 顺时针旋转 270 度。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoOrientation>
A constant List of the values in this enum, in order of their declaration.