VideoPixelFormat enum

视频像素格式。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

videoPixelDefault → const VideoPixelFormat

0: 原始视频像素格式。

videoPixelI420 → const VideoPixelFormat

1: I420 格式。

videoPixelBgra → const VideoPixelFormat

@nodoc

videoPixelNv21 → const VideoPixelFormat

@nodoc

videoPixelRgba → const VideoPixelFormat

4: RGBA 格式。

videoPixelNv12 → const VideoPixelFormat

@nodoc

videoTexture2d → const VideoPixelFormat

@nodoc

videoTextureOes → const VideoPixelFormat

@nodoc

videoCvpixelNv12 → const VideoPixelFormat

@nodoc

videoCvpixelI420 → const VideoPixelFormat

@nodoc

videoCvpixelBgra → const VideoPixelFormat

@nodoc

videoCvpixelP010 → const VideoPixelFormat

@nodoc

videoPixelI422 → const VideoPixelFormat

16: I422 格式。

videoTextureId3d11texture2d → const VideoPixelFormat

17: ID3D11TEXTURE2D 格式。目前支持的类型有 DXGI_FORMAT_B8G8R8A8_UNORM 、 DXGI_FORMAT_B8G8R8A8_TYPELESS 和 DXGI_FORMAT_NV12 。

videoPixelI010 → const VideoPixelFormat

@nodoc

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoPixelFormat>
A constant List of the values in this enum, in order of their declaration.