VideoSubscriptionOptions class

视频订阅设置。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

encodedFrameOnly bool?
是否仅订阅编码后的视频流: true :仅订阅编码后的视频数据(结构化数据),SDK 未对该视频数据做解码及渲染。 false :(默认)订阅原始视频数据和编码后的数据。
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type VideoStreamType?
订阅的视频流类型,默认值为 videoStreamHigh,即订阅视频大流。详见 VideoStreamType 。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited