VideoTranscoderError enum

本地合图错误代码。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

vtErrVideoSourceNotReady → const VideoTranscoderError

1:指定的视频源未开始进行视频采集,你需要为其创建视频轨道并开始视频采集。

vtErrInvalidVideoSourceType → const VideoTranscoderError

2:视频源类型无效,你需要重新指定支持的视频源类型。

vtErrInvalidImagePath → const VideoTranscoderError

3:图片路径无效,你需要重新指定正确的图片路径。

vtErrUnsupportImageFormat → const VideoTranscoderError

4:图片格式无效,需确保图片格式为 PNG、JPEG 或 GIF 中的一种。

vtErrInvalidLayout → const VideoTranscoderError

5:合图后的视频编码分辨率无效。

vtErrInternal → const VideoTranscoderError

20:内部未知错误。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoTranscoderError>
A constant List of the values in this enum, in order of their declaration.