VideoViewSetupMode enum

视图设置模式。

Inheritance
Available extensions
Annotations
  • @JsonEnum.new(alwaysCreate: true)

Values

videoViewSetupReplace → const VideoViewSetupMode

0:(默认) 清除已添加的所有视图、替换为新的视图。

videoViewSetupAdd → const VideoViewSetupMode

1:增加一个视图。

videoViewSetupRemove → const VideoViewSetupMode

2:删除一个视图。 当你不再需要使用某个视图时,建议及时设置 setupMode 为 videoViewSetupRemove 删除视图,否则可能会导致渲染资源泄漏。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VideoViewSetupMode>
A constant List of the values in this enum, in order of their declaration.