WatermarkBuffer class

用于配置水印图像的格式、尺寸和像素缓冲区。

自从 自 v4.6.2 版本新增。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

buffer Uint8List?
水印图像的像素缓冲区数据。
final
format VideoPixelFormat?
水印图像的像素格式,详见 VideoPixelFormat 。
final
hashCode int
The hash code for this object.
no setterinherited
height int?
水印图像的高度,单位为像素。
final
length int?
水印图像缓冲区的长度,单位为字节。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
水印图像的宽度,单位为像素。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited