WatermarkOptions class

配置水印图像。

用于设置要添加的水印图像的相关配置项。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
mode WatermarkFitMode?
水印的适配模式。详见 WatermarkFitMode 。
final
positionInLandscapeMode Rectangle?
水印的适配模式为 fitModeCoverPosition 时,用于设置横屏模式下水印图片的区域。详见 Rectangle 。
final
positionInPortraitMode Rectangle?
水印的适配模式为 fitModeCoverPosition 时,用于设置竖屏模式下水印图片的区域。详见 Rectangle 。
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
visibleInPreview bool?
水印是否在本地预览视图中可见: true : (默认)水印在本地预览视图中可见。 false : 水印在本地预览视图中不可见。
final
watermarkRatio WatermarkRatio?
水印的适配模式为 fitModeUseImageRatio 时,该参数可设置缩放模式下的水印坐标。详见 WatermarkRatio 。
final
zOrder int?
水印图像的图层顺序,默认值为 0。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited