WatermarkRatio class

水印在屏幕中的位置和大小。

水印在屏幕中的位置和大小由 xRatio 、 yRatio 和 widthRatio 共同决定: (xRatio, yRatio) 指水印左上角的坐标,决定水印左上角到屏幕左上角的距离。 widthRatio 决定水印的宽度。

Annotations
  • @JsonSerializable.new(explicitToJson: true, includeIfNull: false)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
widthRatio double?
水印的宽度。SDK 会根据该参数值计算出等比例的水印高度,确保放大或缩小后的水印图片不失真。取值范围为 0.0,1.0,默认值为 0,代表不显示水印。
final
xRatio double?
水印左上角的 x 坐标。以屏幕左上角为原点,x 坐标为水印左上角相对于原点的横向位移。取值范围为 0.0,1.0,默认值为 0。
final
yRatio double?
水印左上角的 y 坐标。以屏幕左上角为原点,y 坐标为水印左上角相对于原点的纵向位移。取值范围为 0.0,1.0,默认值为 0。
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited