AgoraPipContentViewLayout class
画中画视频流的布局配置。
自从 自 v4.6.2 版本新增。 该类定义多个视频流在流式布局中的排列方式,视频流从左到右、从上到下依次排列。
Properties
- column → int?
-
每行的最大视频流数量。达到最大数量后,将开始新行。如果为 null,视频流将流动填充可用宽度。必须大于 0 或为 null。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- padding → int?
-
整个布局周围的内边距,单位为像素。用于在布局边缘和视频流之间创建空间。如果为 null,则不应用内边距。
final
- row → int?
-
布局中允许的最大行数。达到最大行数后,即使存在更多视频流,也不会创建新行。如果为 null,将根据需要创建行以容纳所有视频流。必须大于 0 或为 null。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → int?
-
视频流之间的水平和垂直间距,单位为像素。用于在相邻视频流之间创建一致的间距。如果为 null,视频流将直接相邻放置。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited