AgoraPipController class abstract
管理画中画功能的控制器接口。
自从 自 v4.6.2 版本新增。 此抽象类定义了控制画中画模式所需的方法,包括设置、状态管理和生命周期操作。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - 释放画中画相关的资源。
-
isPipActivated(
) → Future< bool> - 检查画中画模式是否已激活。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pipDispose(
) → Future< void> - 释放画中画相关的资源。
-
pipIsAutoEnterSupported(
) → Future< bool> - 检查是否支持自动进入画中画模式。
-
pipIsSupported(
) → Future< bool> - 检查当前设备是否支持画中画模式。
-
pipSetup(
AgoraPipOptions options) → Future< bool> - 配置画中画模式。
-
pipStart(
) → Future< bool> - 启动画中画模式。
-
pipStop(
) → Future< void> - 停止画中画模式。
-
registerPipStateChangedObserver(
AgoraPipStateChangedObserver observer) → Future< void> - 注册画中画状态改变观测器。
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterPipStateChangedObserver(
) → Future< void> - 取消注册画中画状态改变观测器。
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited