AlphaStitchMode enum
alphaBuffer 和视频帧的相对位置。
Values
- noAlphaStitch → const AlphaStitchMode
-
0:(默认)仅视频帧,即 alphaBuffer 不和视频帧拼接。
- alphaStitchUp → const AlphaStitchMode
-
1: alphaBuffer 位于视频帧的上方。
- alphaStitchBelow → const AlphaStitchMode
-
2: alphaBuffer 位于视频帧的下方。
- alphaStitchLeft → const AlphaStitchMode
-
3: alphaBuffer 位于视频帧的左侧。
- alphaStitchRight → const AlphaStitchMode
-
4: alphaBuffer 位于视频帧的右侧。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlphaStitchMode> - A constant List of the values in this enum, in order of their declaration.