AudioAinsMode enum
AI 降噪的模式。
Values
- ainsModeBalanced → const AudioAinsMode
-
0:(默认)均衡降噪模式;如果你希望实现对噪声抑制和延时都较为均衡的降噪效果,可选择该模式。
- ainsModeAggressive → const AudioAinsMode
-
1:强降噪模式;适用于对噪声抑制性能要求较高的场景,如户外直播。该模式可以更大程度地减少噪声,但同时可能会对语音造成一定损伤。
- ainsModeUltralowlatency → const AudioAinsMode
-
2:低延时强降噪模式。该模式的降噪延时比弱降噪和强降噪模式大约低一半,适用于对降噪及低延时要求较高的场景,如实时合唱。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AudioAinsMode> - A constant List of the values in this enum, in order of their declaration.