AudioEncodedFrameObserver class
编码后音频的观测器。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onMixedAudioEncodedFrame → void Function(Uint8List frameBuffer, int length, EncodedAudioFrameInfo audioEncodedFrameInfo)?
-
获取本地和所有远端用户混音后的音频编码数据。
final
- onPlaybackAudioEncodedFrame → void Function(Uint8List frameBuffer, int length, EncodedAudioFrameInfo audioEncodedFrameInfo)?
-
获取所有远端用户的音频编码数据。
final
- onRecordAudioEncodedFrame → void Function(Uint8List frameBuffer, int length, EncodedAudioFrameInfo audioEncodedFrameInfo)?
-
获取本地用户的音频编码数据。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited