AudioPcmFrame class
外部 PCM 格式音频帧的信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- bytesPerSample → BytesPerSample?
-
音频数据的字节数。
final
- captureTimestamp → int?
-
音频帧的时间戳 (ms)。
final
-
data
→ List<
int> ? -
音频帧数据。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numChannels → int?
-
音频声道数。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRateHz → int?
-
音频采样率 (Hz)。
final
- samplesPerChannel → int?
-
每个声道的采样点数。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited