AudioPcmFrameSink class
该类用于获取原始的 PCM 音频数据。
你可以继承这个类,实现 onFrame 回调来获得 PCM 音频数据。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onFrame → void Function(AudioPcmFrame frame)?
-
已获取音频帧回调。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited