AudioRecordingConfiguration class
录音配置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- encode → bool?
-
设置是否编码音频数据: true : 将音频数据用 AAC 编码。 false :(默认)不编码音频数据,直接保存录制的音频数据。
final
- filePath → String?
-
录音文件在本地保存的绝对路径,需精确到文件名及格式。例如: C:\music\audio.aac 。 请确保你指定的路径存在并且可写。
final
- fileRecordingType → AudioFileRecordingType?
-
录音内容。详见 AudioFileRecordingType 。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- quality → AudioRecordingQualityType?
-
录音音质。详见 audiorecordingqualitytype 。 该参数仅适用于 AAC 文件。
final
- recordingChannel → int?
-
实际录制的音频声道与你采集的音频声道有关:
如果采集的音频为单声道, recordingChannel 设为 2 , 则录制的音频为经过单声道数据拷贝后的双声道数据,而不是立体声。
如果采集的音频为双声道, recordingChannel 设为 1 ,则录制的音频为经过双声道数据混合后的单声道数据。 此外,集成方案也会影响最终录制的音频声道。因此,如果你希望录制立体声,请联系技术支持协助。 录制的音频声道。目前支持如下取值:
1:(默认)单声道。
2: 双声道。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int?
-
如果把该参数设为 44100 或 48000,为保证录音效果,建议录制 WAV 文件或 quality 为 audioRecordingQualityMedium 或 audioRecordingQualityHigh 的 AAC 文件。 录音采样率(Hz)。
16000
32000 (默认)
44100
48000
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited