AudioSessionOperationRestriction enum
SDK 对 Audio Session 的操作权限。
- Inheritance
- Available extensions
- Annotations
-
- @JsonEnum.new(alwaysCreate: true)
Values
- audioSessionOperationRestrictionNone → const AudioSessionOperationRestriction
-
0: 没有限制,SDK 可以对 Audio Session 进行更改。
- audioSessionOperationRestrictionSetCategory → const AudioSessionOperationRestriction
-
1: SDK 不能更改 Audio Session 的 category。
- audioSessionOperationRestrictionConfigureSession → const AudioSessionOperationRestriction
-
2: SDK 不能更改 Audio Session 的 category、mode 或 categoryOptions。
- audioSessionOperationRestrictionDeactivateSession → const AudioSessionOperationRestriction
-
4: 离开频道时,SDK 会保持 Audio Session 处于活动状态,例如在后台播放音频。
- audioSessionOperationRestrictionAll → const AudioSessionOperationRestriction
-
128: 完全限制 SDK 对 Audio Session 的操作权限,SDK 不能再对 Audio Session 进行任何更改。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AudioSessionOperationRestriction> - A constant List of the values in this enum, in order of their declaration.