AudioTrackConfig class
自定义音频轨道的配置选项。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- enableAudioProcessing → bool?
-
该参数设置仅对 audioTrackDirect 类型的自定义音频采集轨道生效。 是否启用音频处理模块: true :启用音频处理模块,应用回声消除 (AEC)、降噪 (ANS) 和自动增益控制 (AGC) 效果。 false :(默认)不启用音频处理模块。
final
- enableLocalPlayback → bool?
-
是否启用本地音频播放: true :(默认) 启用本地音频播放。 false :不启用本地音频播放。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited