AudioVolumeInfo class
用户音量信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid → int?
-
用户 ID。
在本地用户的回调中, uid 为 0。
在远端用户的回调中, uid 为瞬时音量最高的远端用户(最多 3 位)的 ID。
final
- vad → int?
-
vad 无法报告远端用户的人声状态。对于远端用户, vad 的值始终为 1。
如需使用此参数,请在调用 enableAudioVolumeIndication 时设置 reportVad 为 true 。 本地用户的人声状态。
0:本地无人声。
1:本地有人声。
final
- voicePitch → double?
-
本地用户的人声音调(Hz)。取值范围为
0.0,4000.0。 voicePitch 无法报告远端用户的人声音调。对于远端用户, voicePitch 的值始终为 0.0。final - volume → int?
-
用户的音量,取值范围为
0,255。如果用户将自己静音(将 muteLocalAudioStream 设为 true ),但开启了音频采集, volume 的值表示本地采集信号的音量。final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited