CameraStabilizationMode enum
摄像头防抖模式。
摄像头的防抖效果按照 1 < 2 <3 的顺序依次增强,时延也会相应增大。
Values
- cameraStabilizationModeOff → const CameraStabilizationMode
-
-1:(默认)摄像头防抖模式关闭。
- cameraStabilizationModeAuto → const CameraStabilizationMode
-
0:摄像头自动防抖,系统会根据摄像头的状态自动选择一种防抖模式。但是在该模式下的时延较大,建议你不要使用该枚举。
- cameraStabilizationModeLevel1 → const CameraStabilizationMode
-
1:(推荐)摄像头 1 级防抖。
- cameraStabilizationModeLevel2 → const CameraStabilizationMode
-
2:摄像头 2 级防抖。
- cameraStabilizationModeLevel3 → const CameraStabilizationMode
-
3:摄像头 3 级防抖。
- cameraStabilizationModeMaxLevel → const CameraStabilizationMode
-
@nodoc
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CameraStabilizationMode> - A constant List of the values in this enum, in order of their declaration.