ChannelMediaRelayState enum
跨频道媒体流转发状态码。
Values
- relayStateIdle → const ChannelMediaRelayState
-
0: 初始状态。在成功调用 stopChannelMediaRelay 停止跨频道媒体流转发后, onChannelMediaRelayStateChanged 会回调该状态。
- relayStateConnecting → const ChannelMediaRelayState
-
1: SDK 尝试跨频道。
- relayStateRunning → const ChannelMediaRelayState
-
2: 源频道主播成功加入目标频道。
- relayStateFailure → const ChannelMediaRelayState
-
3: 发生异常,详见 onChannelMediaRelayStateChanged 的 code 参数提示的错误信息。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ChannelMediaRelayState> - A constant List of the values in this enum, in order of their declaration.