CompressionPreference enum
视频编码的压缩偏好类型。
Values
- preferCompressionAuto → const CompressionPreference
-
-1:(默认)自动模式。SDK 会根据你设置的视频场景,自动选择 preferLowLatency 或 preferQuality,以获得最佳的用户体验。
- preferLowLatency → const CompressionPreference
-
0: 低延时偏好。SDK 会对视频帧进行压缩处理,以降低延时。该偏好适用于流畅性优先且允许画质降低的场景。
- preferQuality → const CompressionPreference
-
1:高质量偏好。SDK 会对视频帧进行压缩处理,同时保持视频质量。该偏好适用于画质优先的场景。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CompressionPreference> - A constant List of the values in this enum, in order of their declaration.