DegradationPreference enum
带宽受限时的视频编码降级偏好。
Values
- maintainAuto → const DegradationPreference
-
-1:(默认)自动模式。SDK 会根据你设置的视频场景,自动选择 maintainFramerate、maintainBalanced 或 maintainResolution,以获得最优的综合质量体验 (QoE)。
- maintainQuality → const DegradationPreference
-
0:带宽受限时,视频编码时优先降低视频帧率,维持分辨率不变。该降级偏好适用于画质优先的场景。 弃用:该枚举已废弃。请改用其他枚举。
- maintainFramerate → const DegradationPreference
-
1:带宽受限时,视频编码时优先降低视频分辨率,维持视频帧率不变。该降级偏好适用于流畅性优先且允许画质降低的场景。
- maintainBalanced → const DegradationPreference
-
2:带宽受限时,视频编码时同时降低视频帧率和视频分辨率。maintainBalanced 的降幅比 maintainQuality 和 maintainFramerate 降幅更低,适用于流畅性和画质均有限的场景。 本地发送的视频分辨率可能改变,远端用户需能处理这种情况,详见 onVideoSizeChanged 。
- maintainResolution → const DegradationPreference
-
3: 带宽受限时,视频编码时优先降低视频帧率,维持分辨率保持不变。该降级偏好适用于画质优先的场景。
- disabled → const DegradationPreference
-
@nodoc
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DegradationPreference> - A constant List of the values in this enum, in order of their declaration.