DirectCdnStreamingEventHandler class
DirectCdnStreamingEventHandler 接口类用于 SDK 向 App 发送 CDN 推流的事件通知,App 通过继承该接口类的方法获取 SDK 的事件通知。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onDirectCdnStreamingStateChanged → void Function(DirectCdnStreamingState state, DirectCdnStreamingReason reason, String message)?
-
CDN 推流状态改变回调。
final
- onDirectCdnStreamingStats → void Function(DirectCdnStreamingStats stats)?
-
CDN 推流统计数据回调。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited