ExperiencePoorReason enum
接收远端音频时,本地用户主观体验质量较差的原因。
Values
- experienceReasonNone → const ExperiencePoorReason
-
0: 无原因,说明主观体验质量较好。
- remoteNetworkQualityPoor → const ExperiencePoorReason
-
1: 远端用户的网络较差。
- localNetworkQualityPoor → const ExperiencePoorReason
-
2: 本地用户的网络较差。
- wirelessSignalPoor → const ExperiencePoorReason
-
4: 本地用户的 Wi-FI 或者移动数据网络信号弱。
- wifiBluetoothCoexist → const ExperiencePoorReason
-
8: 本地用户同时开启 Wi-Fi 和蓝牙,二者信号互相干扰,导致音频传输质量下降。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ExperiencePoorReason> - A constant List of the values in this enum, in order of their declaration.