ExtensionContext class
插件上下文信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- extensionName → String?
-
插件的名称。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValid → bool?
-
ExtensionContext 中报告的 uid 是否有效: true : uid 有效。 false : uid 无效。
final
- providerName → String?
-
提供插件的服务商名称。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- uid → int?
-
用户 ID。0 代表本地用户,大于 0 代表远端用户。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited