FaceShapeAreaOptions class
滤镜效果选项。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeArea → FaceShapeArea?
-
美型部位,详见 FaceShapeArea 。
final
- shapeIntensity → int?
-
修饰力度。各部位的修饰力度定义(包括修饰的方向、范围、预设值等)有所不同,详见 FaceShapeArea 。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited