FaceShapeBeautyOptions class
美型风格选项。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shapeStyle → FaceShapeBeautyStyle?
-
美型风格,详见 FaceShapeBeautyStyle 。
final
- styleIntensity → int?
-
美型风格强度,取值范围为
0,100,其中默认值为 0.0,表示无美型效果。取值越大,修饰部位的改变越明显。final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited