FaceShapeBeautyStyle enum
美型风格妆特效选项。
自从 自 v4.4.0 版本新增。
Values
- faceShapeBeautyStyleFemale → const FaceShapeBeautyStyle
-
(0):(默认)女性风格妆特效。
- faceShapeBeautyStyleMale → const FaceShapeBeautyStyle
-
(1):男性风格妆特效。
- faceShapeBeautyStyleNatural → const FaceShapeBeautyStyle
-
(2):自然风格妆特效,仅对面部特征进行最小调整。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FaceShapeBeautyStyle> - A constant List of the values in this enum, in order of their declaration.