LiveStreamAdvancedFeature class
转码推流的高级功能配置。
如需使用转码推流高级功能,请联系销售。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- featureName → String?
-
转码推流高级功能的名称,包含 LBHQ(低码率的高清视频功能) 和 VEO(优化的视频编码器功能)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- opened → bool?
-
是否启用转码推流的高级功能: true :开启转码推流的高级功能。 false :(默认)关闭转码推流的高级功能。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited