LocalAccessPointConfiguration class
Local Access Point 配置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- advancedConfig → AdvancedConfigInfo?
-
Local Access Point 的高级选项。详见 AdvancedConfigInfo 。
final
-
domainList
→ List<
String> ? -
Local Access Point 的域名列表。SDK 会根据你填入的域名解析出 Local Access Point 的 IP 地址。域名解析的超时时间为 10 秒。ipList 和 domainList 必须至少填一个。如果你同时指定 IP 地址和域名,SDK 会将根据域名解析出来的 IP 地址和你指定的 IP 地址合并、去重,然后随机连接一个 IP 来实现负载均衡。
final
- domainListSize → int?
-
Local Access Point 域名的数量。该参数的值必须和你填入的域名的数量一致。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
ipList
→ List<
String> ? -
Local Access Point 的对内 IP 地址列表。ipList 和 domainList 必须至少填一个。
final
- ipListSize → int?
-
Local Access Point 对内 IP 地址的数量。该参数的值必须和你填入的 IP 地址的数量一致。
final
- mode → LocalProxyMode?
-
连接模式。详见 LocalProxyMode 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyDomainName → String?
-
内网证书验证域名。如果传值为空,则用 SDK 默认的证书验证域名 secure-edge.local 。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited