LocalVideoStats class
本地视频流统计信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- captureBrightnessLevel → CaptureBrightnessLevelType?
-
本地采集的画质亮度级别。详见 CaptureBrightnessLevelType 。
final
- captureFrameHeight → int?
-
本地视频采集高度 (px)。
final
- captureFrameRate → int?
-
本地视频采集帧率 (fps)。
final
- captureFrameWidth → int?
-
本地视频采集宽度 (px)。
final
- codecType → VideoCodecType?
-
视频的编码类型。详见 VideoCodecType 。
final
- encodedBitrate → int?
-
视频编码码率(Kbps)。 不包含丢包后重传视频等的编码码率。
final
- encodedFrameCount → int?
-
视频发送的帧数,累计值。
final
- encodedFrameHeight → int?
-
视频编码高度(px)。
final
- encodedFrameWidth → int?
-
视频编码宽度(px)。
final
- encoderOutputFrameRate → int?
-
本地视频编码器的输出帧率,单位为 fps。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hwEncoderAccelerating → int?
-
本地视频编码加速类型。
0:采用软件编码,未加速。
1:采用硬件编码进行加速。
final
- qualityAdaptIndication → QualityAdaptIndication?
-
统计周期内本地视频质量(基于目标帧率和目标码率)的自适应情况。详见 QualityAdaptIndication 。
final
- regulatedCaptureFrameHeight → int?
-
SDK 内置的视频采集适配器(regulator)调整后的摄像头采集视频高度 (px)。Regulator 根据视频编码配置对摄像头采集视频的宽高进行调整。
final
- regulatedCaptureFrameRate → int?
-
SDK 内置的视频采集适配器(regulator)调整后的摄像头采集视频帧率 (fps)。Regulator 根据视频编码配置对摄像头采集视频的帧率进行调整。
final
- regulatedCaptureFrameWidth → int?
-
SDK 内置的视频采集适配器(regulator)调整后的摄像头采集视频宽度 (px)。Regulator 根据视频编码配置对摄像头采集视频的宽高进行调整。
final
- rendererOutputFrameRate → int?
-
本地视频渲染器的输出帧率,单位为 fps。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sentBitrate → int?
-
实际发送码率 (Kbps) 不包含丢包后重传视频等的发送码率。
final
- sentFrameRate → int?
-
实际发送帧率 (fps)。 不包含丢包后重传视频等的发送帧率。
final
- targetBitrate → int?
-
当前编码器的目标编码码率 (Kbps),该码率为 SDK 根据当前网络状况预估的一个值。
final
- targetFrameRate → int?
-
当前编码器的目标编码帧率 (fps)。
final
- txPacketLossRate → int?
-
弱网对抗前本端到声网边缘服务器的视频丢包率 (%)。
final
- uid → int?
-
本地用户的 ID。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited