LogConfig class
SDK 日志文件的配置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- filePath → String?
-
日志文件的完整路径。声网建议你使用默认的日志路径。如果你需要修改默认的日志路径,请确保你指定的路径存在且可写。
final
- fileSizeInKB → int?
-
单个 agorasdk.log 日志文件的大小,单位为 KB,取值范围为
128,20480,默认值为 2,048 KB。如果你将 fileSizeInKByte 设为小于 128 KB,SDK 会自动调整到 128 KB;如果你将 fileSizeInKByte 设为大于 20,480 KB,SDK 会自动调整到 20,480 KB。final - hashCode → int
-
The hash code for this object.
no setterinherited
- level → LogLevel?
-
SDK 的日志输出等级,详见 LogLevel 。
例如,如果你选择 WARN 级别,就可以看到在 FATAL、ERROR 和 WARN 级别上的所有日志信息。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited