LogLevel enum
日志输出等级。
Values
- logLevelNone → const LogLevel
-
0: 不输出任何日志。
- logLevelInfo → const LogLevel
-
0x0001:(默认)输出 FATAL 、 ERROR 、 WARN 、 INFO 级别的日志。建议你将日志级别设为该等级。
- logLevelWarn → const LogLevel
-
0x0002: 仅输出 FATAL 、 ERROR 、 WARN 级别的日志。
- logLevelError → const LogLevel
-
0x0004: 仅输出 FATAL 、 ERROR 级别的日志。
- logLevelFatal → const LogLevel
-
0x0008: 仅输出 FATAL 级别的日志。
- logLevelApiCall → const LogLevel
-
@nodoc
- logLevelDebug → const LogLevel
-
@nodoc
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited