MediaPlayerEvent enum
播放器事件。
Values
- playerEventSeekBegin → const MediaPlayerEvent
-
0: 开始定位。
- playerEventSeekComplete → const MediaPlayerEvent
-
1: 完成定位。
- playerEventSeekError → const MediaPlayerEvent
-
2: 定位出错。
- playerEventAudioTrackChanged → const MediaPlayerEvent
-
5: 当前音轨发生改变。
- playerEventBufferLow → const MediaPlayerEvent
-
6: 当前缓冲的数据不足以支持播放。
- playerEventBufferRecover → const MediaPlayerEvent
-
7: 当前缓冲的数据刚好能支持播放。
- playerEventFreezeStart → const MediaPlayerEvent
-
8: 音频或视频出现卡顿。
- playerEventFreezeStop → const MediaPlayerEvent
-
9: 音频和视频均停止卡顿。
- playerEventSwitchBegin → const MediaPlayerEvent
-
10: 开始切换媒体资源。
- playerEventSwitchComplete → const MediaPlayerEvent
-
11: 媒体资源切换完成。
- playerEventSwitchError → const MediaPlayerEvent
-
12: 媒体资源切换出错。
- playerEventFirstDisplayed → const MediaPlayerEvent
-
13: 视频首帧出图。
- playerEventReachCacheFileMaxCount → const MediaPlayerEvent
-
14:达到可缓存文件的数量上限。
- playerEventReachCacheFileMaxSize → const MediaPlayerEvent
-
15:达到可缓存文件的大小上限。
- playerEventTryOpenStart → const MediaPlayerEvent
-
@nodoc
- playerEventTryOpenSucceed → const MediaPlayerEvent
-
@nodoc
- playerEventTryOpenFailed → const MediaPlayerEvent
-
@nodoc
- playerEventHttpRedirect → const MediaPlayerEvent
-
@nodoc
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MediaPlayerEvent> - A constant List of the values in this enum, in order of their declaration.