MediaPlayerReason enum
播放器状态改变的原因。
Values
- playerReasonNone → const MediaPlayerReason
-
0: 没有错误。
- playerReasonInvalidArguments → const MediaPlayerReason
-
-1: 不正确的参数。
- playerReasonInternal → const MediaPlayerReason
-
-2: 内部错误。
- playerReasonNoResource → const MediaPlayerReason
-
-3: 没有 resource。
- playerReasonInvalidMediaSource → const MediaPlayerReason
-
-4: 无效的 resource。
- playerReasonUnknownStreamType → const MediaPlayerReason
-
-5: 未知的媒体流类型。
- playerReasonObjNotInitialized → const MediaPlayerReason
-
-6: 对象没有初始化。
- playerReasonCodecNotSupported → const MediaPlayerReason
-
-7: 解码器不支持该 codec。
- playerReasonVideoRenderFailed → const MediaPlayerReason
-
-8: 无效的 renderer。
- playerReasonInvalidState → const MediaPlayerReason
-
-9: 播放器内部状态错误。
- playerReasonUrlNotFound → const MediaPlayerReason
-
-10: 未找到该 URL。
- playerReasonInvalidConnectionState → const MediaPlayerReason
-
-11: 播放器与声网服务器的连接无效。
- playerReasonSrcBufferUnderflow → const MediaPlayerReason
-
-12: 播放缓冲区数据不足。
- playerReasonInterrupted → const MediaPlayerReason
-
-13: 播放被异常打断而结束。
- playerReasonNotSupported → const MediaPlayerReason
-
-14: SDK 不支持的接口调用。
- playerReasonTokenExpired → const MediaPlayerReason
-
-15: 媒体资源网络路径的鉴权信息已过期。
- playerReasonIpExpired → const MediaPlayerReason
-
@nodoc
- playerReasonUnknown → const MediaPlayerReason
-
-17:未知错误。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MediaPlayerReason> - A constant List of the values in this enum, in order of their declaration.