MediaPlayerVideoFrameObserver class
媒体播放器的视频数据观测器。
你可以调用 registerVideoFrameObserver 注册或取消注册 MediaPlayerVideoFrameObserver 观测器。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onFrame → void Function(VideoFrame frame)?
-
已获取视频帧回调。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited