MediaRecorder class abstract
提供本地及远端音视频录制功能的类。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setMediaRecorderObserver(
MediaRecorderObserver callback) → Future< void> - 注册 MediaRecorderObserver 观测器。
-
startRecording(
MediaRecorderConfiguration config) → Future< void> - 开启音视频流录制。
-
stopRecording(
) → Future< void> - 停止音视频流录制。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited