MediaRecorderObserver class
包含音视频录制的事件。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onRecorderInfoUpdated → void Function(String channelId, int uid, RecorderInfo info)?
-
录制信息更新回调。
final
- onRecorderStateChanged → void Function(String channelId, int uid, RecorderState state, RecorderReasonCode reason)?
-
录制状态发生改变回调。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited