MultipathMode enum
多路径数据传输的模式。
自从 自 v4.6.2 版本新增。
Values
- duplicate → const MultipathMode
-
(0):冗余发送模式,相同的数据会通过所有可用路径进行冗余传输。
- dynamic → const MultipathMode
-
(1):动态发送模式,SDK 会根据当前网络状况动态选择最优路径进行数据传输,以提升传输性能。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
MultipathMode> - A constant List of the values in this enum, in order of their declaration.