MultipathStats class
用于汇总多路径传输中各网络路径的统计数据。
自从 自 v4.6.2 版本新增。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- activePathNum → int?
-
当前活跃的传输路径数量。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lanRxBytes → int?
-
通过 LAN 路径接收的字节总数。
final
- lanTxBytes → int?
-
通过 LAN 路径发送的字节总数。
final
- mobileRxBytes → int?
-
通过移动网络路径接收的字节总数。
final
- mobileTxBytes → int?
-
通过移动网络路径发送的字节总数。
final
-
pathStats
→ List<
PathStats> ? -
每个活跃传输路径的统计信息数组。详见 PathStats 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- wifiRxBytes → int?
-
通过 Wi-Fi 路径接收的字节总数。
final
- wifiTxBytes → int?
-
通过 Wi-Fi 路径发送的字节总数。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited