Music class
音乐资源的详细信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- climaxSegmentCount → int?
-
高潮片段的数量。
final
-
climaxSegmentList
→ List<
ClimaxSegment> ? -
音乐高潮片段列表,详见 ClimaxSegment 。
final
- durationS → int?
-
音乐资源总时长 (秒)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- lyricCount → int?
-
歌曲的歌词数量。
final
-
lyricList
→ List<
int> ? -
支持的歌词类型:
0:xml 格式。
1:lrc 格式。
final
- name → String?
-
音乐资源名称。
final
- pitchType → int?
-
歌曲是否支持演唱评分功能:
1:歌曲支持演唱评分功能。
2:歌曲不支持演唱评分功能。
final
- poster → String?
-
音乐资源海报的下载地址。
final
- releaseTime → String?
-
音乐资源发布的时间。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- singer → String?
-
歌手名。
final
- songCode → int?
-
音乐资源的编号,用于标识一个音乐资源。
final
- type → int?
-
音乐资源类型:
1:左声道伴奏,右声道原唱的单音轨音源。
2:只有伴唱的单音轨音源。
3:只有原唱的单音轨音源。
4:多音轨音源。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited