MusicContentCenter class abstract
MusicContentCenter 接口类提供音乐内容中心的相关方法。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createMusicPlayer(
) → Future< MusicPlayer?> - 创建音乐播放器。
-
destroyMusicPlayer(
MusicPlayer musicPlayer) → Future< void> - 销毁音乐播放器对象。
-
getCaches(
int cacheInfoSize) → Future< List< MusicCacheInfo> > - 获取已缓存的音乐资源信息。
-
getInternalSongCode(
{required int songCode, required String jsonOption}) → Future< int> - 创建音乐资源的副歌片段编号。
-
getLyric(
{required int songCode, int lyricType = 0}) → Future< String> - 获取音乐资源的歌词下载地址。
-
getMusicCharts(
) → Future< String> - 获取全部音乐榜单。
-
getMusicCollectionByMusicChartId(
{required int musicChartId, required int page, required int pageSize, String? jsonOption}) → Future< String> - 通过音乐榜单的 ID 获取指定榜单的音乐资源列表。
-
getSongSimpleInfo(
int songCode) → Future< String> - 获取某一音乐资源的详细信息。
-
initialize(
MusicContentCenterConfiguration configuration) → Future< void> - 初始化 MusicContentCenter 。
-
isPreloaded(
int songCode) → Future< bool> - 检测音乐资源是否已被预加载。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
preload(
int songCode) → Future< String> - 预加载音乐资源。
-
registerEventHandler(
MusicContentCenterEventHandler eventHandler) → void - 注册音乐内容中心回调事件。
-
release(
) → Future< void> - 释放音乐内容中心所占用的所有资源。
-
removeCache(
int songCode) → Future< void> - 删除已缓存的音乐资源。
-
renewToken(
String token) → Future< void> - 更新 Token。
-
searchMusic(
{required String keyWord, required int page, required int pageSize, String? jsonOption}) → Future< String> - 搜索音乐资源。
-
toString(
) → String -
A string representation of this object.
inherited
-
unregisterEventHandler(
) → void - 取消注册音乐内容中心事件回调。
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited