MusicContentCenterConfiguration class
音乐内容中心的设置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- appId → String?
-
已启用内容中心的项目的 App ID。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxCacheSize → int?
-
可缓存的音乐资源数量,最多不能超过 50。
final
- mccUid → int?
-
使用音乐内容中心的用户 ID,该 ID 可以和你加入 RTC 频道时使用的 uid 一致,但不能为 0。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String?
-
使用音乐内容中心时,用于鉴权的 RTM Token。
声网推荐你使用 AccessToken2 进行鉴权,详见部署 Token 服务器。生成 Token 时,请向 uid 传入 String 型的 mccUid 。
当你的 Token 即将过期时,你可以调用 renewToken 来传入新的 Token。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited