PlayerStreamInfo class
播放器媒体流的所有信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- audioBitsPerSample → int?
-
该参数仅对音频流生效,表示每个音频采样点的位数 (bit)。
final
- audioChannels → int?
-
该参数仅对音频流生效,表示声道数。
final
- audioSampleRate → int?
-
该参数仅对音频流生效,表示音频采样率 (Hz)。
final
- codecName → String?
-
此条媒体流的编码规格。
final
- duration → int?
-
媒体流的时长(毫秒)。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String?
-
此条媒体流的语言。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- streamIndex → int?
-
媒体流的索引值。
final
- streamType → MediaStreamType?
-
此条媒体流的类型。详见 MediaStreamType 。
final
- videoBitRate → int?
-
该参数仅对视频流生效,表示视频码率 (bps)。
final
- videoFrameRate → int?
-
该参数仅对视频流生效,表示视频帧率 (fps)。
final
- videoHeight → int?
-
该参数仅对视频流生效,表示视频高度 (px)。
final
- videoRotation → int?
-
该参数仅对视频流生效,表示旋转角度。
final
- videoWidth → int?
-
该参数仅对视频流生效,表示视频宽度 (px)。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited