PlayerUpdatedInfo class
媒体播放器相关信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- audioBitsPerSample → int?
-
每个音频采样点的位数 (bit)。
final
- audioChannels → int?
-
声道数。
final
- audioSampleRate → int?
-
音频采样率 (Hz)。
final
- deviceId → String?
-
设备 ID,标识一个设备。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoHeight → int?
-
视频高度 (pixel)。
final
- videoWidth → int?
-
视频宽度 (pixel)。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited