QualityAdaptIndication enum
自上次统计后本地视频质量的自适应情况(基于目标帧率和目标码率)。
Values
- adaptNone → const QualityAdaptIndication
-
0:本地视频质量不变。
- adaptUpBandwidth → const QualityAdaptIndication
-
1:因网络带宽增加,本地视频质量改善。
- adaptDownBandwidth → const QualityAdaptIndication
-
2:因网络带宽减少,本地视频质量变差。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
QualityAdaptIndication> - A constant List of the values in this enum, in order of their declaration.