RemoteAudioState enum
远端音频流状态。
Values
- remoteAudioStateStopped → const RemoteAudioState
-
0: 远端音频默认初始状态。在 remoteAudioReasonLocalMuted 、 remoteAudioReasonRemoteMuted 或 remoteAudioReasonRemoteOffline 的情况下,会报告该状态。
- remoteAudioStateStarting → const RemoteAudioState
-
1: 本地用户已接收远端音频首包。
- remoteAudioStateDecoding → const RemoteAudioState
-
2: 远端音频流正在解码,正常播放。在 remoteAudioReasonNetworkRecovery 、 remoteAudioReasonLocalUnmuted 或 remoteAudioReasonRemoteUnmuted 的情况下,会报告该状态。
- remoteAudioStateFrozen → const RemoteAudioState
-
3: 远端音频流卡顿。在 remoteAudioReasonNetworkCongestion 的情况下,会报告该状态。
- remoteAudioStateFailed → const RemoteAudioState
-
4: 远端音频流播放失败。在 remoteAudioReasonInternal 的情况下,会报告该状态。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RemoteAudioState> - A constant List of the values in this enum, in order of their declaration.