RemoteAudioStateReason enum
远端音频流状态切换原因。
Values
- remoteAudioReasonInternal → const RemoteAudioStateReason
-
0: 音频状态发生改变时,会报告该原因。
- remoteAudioReasonNetworkCongestion → const RemoteAudioStateReason
-
1: 网络阻塞。
- remoteAudioReasonNetworkRecovery → const RemoteAudioStateReason
-
2: 网络恢复正常。
- remoteAudioReasonLocalMuted → const RemoteAudioStateReason
-
3: 本地用户停止接收远端音频流或本地用户禁用音频模块。
- remoteAudioReasonLocalUnmuted → const RemoteAudioStateReason
-
4: 本地用户恢复接收远端音频流或本地用户启动音频模块。
- remoteAudioReasonRemoteMuted → const RemoteAudioStateReason
-
5: 远端用户停止发送音频流或远端用户禁用音频模块。
- remoteAudioReasonRemoteUnmuted → const RemoteAudioStateReason
-
6: 远端用户恢复发送音频流或远端用户启用音频模块。
- remoteAudioReasonRemoteOffline → const RemoteAudioStateReason
-
7: 远端用户离开频道。
- remoteAudioReasonNoPacketReceive → const RemoteAudioStateReason
-
@nodoc
- remoteAudioReasonLocalPlayFailed → const RemoteAudioStateReason
-
@nodoc
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RemoteAudioStateReason> - A constant List of the values in this enum, in order of their declaration.