RtcEngineContext class
RtcEngineContext 定义。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- appId → String?
-
声网为 App 开发者签发的 App ID。 使用同一个 App ID 的 App 才能进入同一个频道进行通话或直播。一个 App ID 只能用于创建一个 RtcEngine 。如需更换 App ID,必须先调用 release 销毁当前 RtcEngine 再重新创建。
final
- areaCode → int?
-
服务器的访问区域。该功能为高级设置,适用于有访问安全限制的场景。支持的区域详见 AreaCode 。区域码支持位操作。
final
- audioScenario → AudioScenarioType?
-
音频场景。不同的音频场景下,设备的音量类型是不同的。
详见 AudioScenarioType 。
final
- autoRegisterAgoraExtensions → bool?
-
是否在初始化 RtcEngine 时自动注册声网插件: true :(默认)初始化 RtcEngine 时自动注册声网插件。 false :初始化 RtcEngine 时不注册声网插件。你需要调用 enableExtension 来注册声网插件。
final
- channelProfile → ChannelProfileType?
-
频道使用场景。详见 ChannelProfileType 。
final
- domainLimit → bool?
-
是否开启域名限制: true :开启域名限制。该设置适用于 IoT 设备使用物联网卡进行网络访问的场景。SDK 会仅连接到已向运营商报备的域名或 IP 白名单中的服务器。 false :(默认)关闭域名限制。该设置适用于大部分普通场景。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- logConfig → LogConfig?
-
设置 SDK 输出的日志文件。详见 LogConfig 。
默认情况下,SDK 会生成 5 个 SDK 日志文件和 5 个 API 调用日志文件,规则如下:
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited