RtmpStreamingEvent enum
旁路推流时发生的事件。
Values
- rtmpStreamingEventFailedLoadImage → const RtmpStreamingEvent
-
1: 旁路推流时,添加背景图或水印出错。
- rtmpStreamingEventUrlAlreadyInUse → const RtmpStreamingEvent
-
2: 该推流 URL 已用于推流。如果你想开始新的推流,请使用新的推流 URL。
- rtmpStreamingEventAdvancedFeatureNotSupport → const RtmpStreamingEvent
-
3: 功能不支持。
- rtmpStreamingEventRequestTooOften → const RtmpStreamingEvent
-
4: 预留参数。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RtmpStreamingEvent> - A constant List of the values in this enum, in order of their declaration.