ScreenAudioParameters class
共享屏幕流的音频配置。
仅适用于 captureAudio 为 true 的场景。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- captureSignalVolume → int?
-
采集的系统音量。取值范围为
0,100。默认值为 100。final - channels → int?
-
声道数。默认值为 2,表示双声道。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sampleRate → int?
-
音频采样率 (Hz)。默认值为 16000。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited