ScreenCaptureSourceInfo class
可共享窗口或屏幕的信息。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- iconImage → ThumbImageBuffer?
-
图标的图像内容。详见 ThumbImageBuffer 。
final
- minimizeWindow → bool?
-
(仅适用于 Windows) 窗口是否已最小化: true : 窗口已最小化。 false : 窗口未最小化。
final
- position → Rectangle?
-
窗口相对于整个屏幕空间(包含所有可共享屏幕)的位置。详见 Rectangle 。
final
- primaryMonitor → bool?
-
屏幕是否为主显示屏: true : 屏幕为主显示屏。 false : 屏幕不是主显示屏。
final
- processPath → String?
-
窗口所属的进程。UTF-8 编码。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceDisplayId → int?
-
(仅适用于 Windows) 窗口所在的屏幕 ID。如果窗口为跨屏幕显示,则表示与该窗口相交面积最大的屏幕 ID。如果窗口位于可见屏幕之外,则该成员的值为 -2。
final
- sourceId → int?
-
对于窗口,表示窗口 ID(Window ID);对于屏幕,表示屏幕 ID(Display ID)。
final
- sourceName → String?
-
窗口或屏幕的名称。UTF-8 编码。
final
- sourceTitle → String?
-
窗口标题。UTF-8 编码。
final
- thumbImage → ThumbImageBuffer?
-
缩略图的图像内容。详见 ThumbImageBuffer 。
final
- type → ScreenCaptureSourceType?
-
共享目标的类型。详见 ScreenCaptureSourceType 。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited