SegmentationProperty class
背景图像的处理属性。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- greenCapacity → double?
-
对画面中背景颜色识别的精度范围。取值范围为
0,1,默认值为 0.5。取值越大,代表可识别的纯色范围越大。当该参数取值过大时,人像边缘和人像范围内的纯色也会被识别。建议你根据实际效果动态调整该参数的值。 该参数仅在 modelType 设置为 segModelGreen 时生效。final - hashCode → int
-
The hash code for this object.
no setterinherited
- modelType → SegModelType?
-
进行背景处理的算法。详见 SegModelType 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- screenColorType → ScreenColorType?
-
屏幕颜色类型。详见 ScreenColorType 。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited