SimulcastStreamConfig class
视频小流的配置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- dimensions → VideoDimensions?
-
视频尺寸。详见 VideoDimensions 。默认值为视频大流的 50%。
final
- framerate → int?
-
视频帧率 (fps)。默认值为 5。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kBitrate → int?
-
视频码率 (Kbps),默认值为 -1。该参数无需设置,SDK 会根据你设定的视频分辨率和帧率自动匹配最合适的码率。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited