SnapshotConfig class
视频截图设置。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- filePath → String?
-
请确保目录存在且可写。 截图的本地保存路径,需精确到文件名及格式,例如:
Windows: C:\Users<user_name>\AppData\Local\Agora<process_name>\example.jpg
iOS: /App Sandbox/Library/Caches/example.jpg
macOS: ~/Library/Logs/example.jpg
Android: /storage/emulated/0/Android/data/
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → VideoModulePosition?
-
截图的视频帧在视频链路中的位置。详见 VideoModulePosition 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited