StreamFallbackOptions enum
网络条件较差时,音视频流回退处理的选项。
Values
- streamFallbackOptionDisabled → const StreamFallbackOptions
-
0: 不对音视频流作回退处理,但不能保证音视频流的质量。
- streamFallbackOptionVideoStreamLow → const StreamFallbackOptions
-
1: 只接收视频小流(低分辨率、低码率视频流)。
- streamFallbackOptionAudioOnly → const StreamFallbackOptions
-
2: 网络条件较差时,先尝试只接收视频小流;如果因网络环境太差无法显示视频,则再回退到只接收订阅的音频流。
- streamFallbackOptionVideoStreamLayer1 → const StreamFallbackOptions
-
@nodoc
- streamFallbackOptionVideoStreamLayer2 → const StreamFallbackOptions
-
@nodoc
- streamFallbackOptionVideoStreamLayer3 → const StreamFallbackOptions
-
@nodoc
- streamFallbackOptionVideoStreamLayer4 → const StreamFallbackOptions
-
@nodoc
- streamFallbackOptionVideoStreamLayer5 → const StreamFallbackOptions
-
@nodoc
- streamFallbackOptionVideoStreamLayer6 → const StreamFallbackOptions
-
@nodoc
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
StreamFallbackOptions> - A constant List of the values in this enum, in order of their declaration.