ThumbImageBuffer class
缩略图或图标的图像内容。在 ScreenCaptureSourceInfo 中设置。
图像默认为 ARGB 格式。如果你需要使用其他格式,请自行转换格式。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- buffer → Uint8List?
-
缩略图或图标的 buffer。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → int?
-
缩略图或图标的实际高度(px)。
final
- length → int?
-
缩略图或图标的 buffer 长度,单位为字节。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- width → int?
-
缩略图或图标的实际宽度(px)。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited