VideoCanvas class
视频画布对象的属性。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- backgroundColor → int?
-
视频画布的背景颜色,格式为 RGBA。默认值为 0x00000000,代表黑色。
final
- cropArea → Rectangle?
-
(可选)视频帧的展示区域,详见 Rectangle 。其中, width 和 height 表示该区域的视频像素宽度和高度。默认值为空值 (宽或高为 0),表示展示实际分辨率的视频帧。
final
- enableAlphaMask → bool?
-
仅当发送端开启 Alpha 传输功能时,接收端才能渲染 Alpha 通道的信息。
如需开启 Alpha 传输功能,请联系技术支持。 (可选)是否开启 Alpha 遮罩渲染: true :开启 Alpha 遮罩渲染。 false :(默认)关闭 Alpha 遮罩渲染。 Alpha 遮罩渲染可以创建具有透明效果的图像,还可以提取视频中的人像。与其他方法结合使用时,可以实现人像画中画、添加水印等效果。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mediaPlayerId → int?
-
媒体播放器 ID。可通过 getMediaPlayerId 获取。
final
- mirrorMode → VideoMirrorModeType?
-
视图镜像模式,详见 VideoMirrorModeType 。
本地视图镜像模式:如果你使用前置摄像头,默认启动本地视图镜像模式;如果你使用后置摄像头,默认关闭本地视图镜像模式。
远端用户视图镜像模式:默认关闭远端用户的镜像模式。
final
- position → VideoModulePosition?
-
视频帧在视频链路中的位置。详见 VideoModulePosition 。
final
- renderMode → RenderModeType?
-
视频渲染模式,详见 RenderModeType 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- setupMode → VideoViewSetupMode?
-
视图设置模式。详见 VideoViewSetupMode 。
final
- sourceType → VideoSourceType?
-
视频源的类型,详见 VideoSourceType 。
final
- subviewUid → int?
-
发布某一路合图子视频流的用户 ID。
final
- uid → int?
-
对于 Android 和 iOS 平台,当视频源为合图视频流 (videoSourceTranscoded) 时,该参数表示发布合图视频流的用户 ID。
final
- view → int?
-
视频显示窗口。 在一个 VideoCanvas 中,你只能选择 view 或 surfaceTexture 其中一个进行设置,如果同时设置,只有 view 中的设置会生效。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited