VideoCodecCapabilityLevel enum
视频编解码能力等级。
Values
- codecCapabilityLevelUnspecified → const VideoCodecCapabilityLevel
-
-1:不支持的视频类型。目前仅支持对 H.264 和 H.265 格式的视频进行查询,如果视频为其他格式,则返回该值。
- codecCapabilityLevelBasicSupport → const VideoCodecCapabilityLevel
-
5:基本的编解码支持,即:对 1080p、30 fps 以下的视频进行编解码。
- codecCapabilityLevel1080p30fps → const VideoCodecCapabilityLevel
-
10:最高支持对 1080p、30 fps 的视频进行编解码。
- codecCapabilityLevel1080p60fps → const VideoCodecCapabilityLevel
-
20:最高支持对 1080p、60 fps 的视频进行编解码。
- codecCapabilityLevel4k60fps → const VideoCodecCapabilityLevel
-
30:最高支持对 4K、30 fps 的视频进行编解码。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoCodecCapabilityLevel> - A constant List of the values in this enum, in order of their declaration.