VideoDeviceManager class abstract
视频设备管理方法。
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
enumerateVideoDevices(
) → Future< List< VideoDeviceInfo> > - 获取系统中所有的视频设备列表。
-
getCapability(
{required String deviceIdUTF8, required int deviceCapabilityNumber}) → Future< VideoFormat> - 获取视频采集设备在指定的视频格式下的详细视频帧信息。
-
getDevice(
) → Future< String> - 获取当前使用的视频采集设备。
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
numberOfCapabilities(
String deviceIdUTF8) → Future< int> - 获取指定视频采集设备支持的视频格式数量。
-
release(
) → Future< void> - 释放 VideoDeviceManager 对象占用的所有资源。
-
setDevice(
String deviceIdUTF8) → Future< void> - 通过设备 ID 指定视频采集设备。
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited