VideoFrameObserver class
视频观测器。
你可以调用 registerVideoFrameObserver 注册或取消注册 VideoFrameObserver 视频观测器。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onCaptureVideoFrame → void Function(VideoSourceType sourceType, VideoFrame videoFrame)?
-
获取本地设备采集到的视频数据。
final
- onPreEncodeVideoFrame → void Function(VideoSourceType sourceType, VideoFrame videoFrame)?
-
获取本地视频编码前的视频数据。
final
- onRenderVideoFrame → void Function(String channelId, int remoteUid, VideoFrame videoFrame)?
-
获取远端发送的视频数据。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited