VideoFrameProcessMode enum
视频帧处理模式。
Values
- processModeReadOnly → const VideoFrameProcessMode
-
只读模式。 只读模式下,你不修改视频帧,视频观测器相当于渲染器。
- processModeReadWrite → const VideoFrameProcessMode
-
读写模式。 读写模式下,你会修改视频帧,视频观测器相当于视频 filter。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoFrameProcessMode> - A constant List of the values in this enum, in order of their declaration.