VideoModulePosition enum
视频观测位置。
Values
- positionPostCapturer → const VideoModulePosition
-
1: 本地采集视频数据并且经过前处理之后的位置,对应 onCaptureVideoFrame 回调。此处观测到的视频具备视频前处理的效果,可通过开启美颜、虚拟背景或水印等方式验证。
- positionPreRenderer → const VideoModulePosition
-
2: 接收远端发送的视频在渲染前的位置,对应 onRenderVideoFrame 回调。
- positionPreEncoder → const VideoModulePosition
-
4: 本地视频编码前的位置,对应 onPreEncodeVideoFrame 回调。此处观测到的视频具备视频前处理和编码前处理的效果: 对于视频前处理效果,可通过开启美颜、虚拟背景或水印等方式验证。 对于编码前处理效果,可通过设置一个较低的帧率(例如 5 fps)验证。
- positionPostCapturerOrigin → const VideoModulePosition
-
8: 本地采集视频之后、前处理之前的位置。此处观测到的视频不具备前处理的效果,可通过开启美颜、虚拟背景或设置水印等方式验证。
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
VideoModulePosition> - A constant List of the values in this enum, in order of their declaration.