VideoViewController class
AgoraVideoView 的控制器,用于渲染本地和远端视频。
在不同平台上,该类对应的默认视图不同: Android: https://developer.android.com/reference/android/view/TextureView 。如果你想要使用 SurfaceView ,则设置 useAndroidSurfaceView 的属性为 true 。 iOS: UIView 。如果你想要使用 FlutterTexture ,则设置 useFlutterTexture 的属性为 true 。 macOS 和 Windows:FlutterTexture 。
- Implemented types
Properties
- canvas → VideoCanvas
-
本地视频显示属性。详见 VideoCanvas 。
final
- connection → RtcConnection
-
Connection 信息。详见 RtcConnection 。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- rtcEngine → RtcEngine
-
RtcEngine 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- useAndroidSurfaceView → bool
-
Android SurfaceView 仅适用于 Android 平台。 是否使用 Android SurfaceView 渲染视频: true : 使用 Android SurfaceView 渲染视频。 false : 不使用 Android SurfaceView 渲染视频。
final
- useFlutterTexture → bool
-
FlutterTexture 仅适用于 iOS、macOS 和 Windows 平台。 是否使用 FlutterTexture 渲染视频: true : 使用 FlutterTexture 渲染视频。 false : 不使用 FlutterTexture 渲染视频。
final
Methods
-
addPlatformRenderRef(
int platformViewId) → Future< void> -
inherited
-
createTextureRender(
int uid, String channelId, int videoSourceType, int videoViewSetupMode) → Future< int> -
inherited
-
dePlatformRenderRef(
int platformViewId) → Future< void> -
inherited
-
dispose(
) → Future< void> -
@nodoc
inherited
-
disposeRenderInternal(
) → Future< void> -
inherited
-
getPlatformViewId(
) → int -
inherited
-
getTextureId(
) → int -
inherited
-
getVideoSourceType(
) → int -
getViewHandle(
) → int -
inherited
-
initializeRender(
) → Future< void> -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setupView(
int platformViewId, int nativeViewPtr) → Future< void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited