VirtualBackgroundSource class
自定义的背景。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- backgroundSourceType → BackgroundSourceType?
-
自定义的背景。详见 backgroundSourceType 。
final
- blurDegree → BackgroundBlurDegree?
-
自定义背景图的模糊程度。 该参数仅在自定义背景图类型为 backgroundBlur 时生效。
final
- color → int?
-
自定义的背景图颜色。格式为 RGB 定义下的十六进制整数,不带 # 号,如 0xFFB6C1 表示浅粉色。 默认值为 0xFFFFFF,表示白色。 取值范围为
0x000000,0xffffff。如果取值非法,SDK 会用白色背景图替换原背景图。 该参数仅在自定义背景为以下类型时生效,具体效果如下: backgroundColor:背景图为该参数传入颜色的纯色图片。 backgroundImg:如果 source 中的图片使用了透明背景,则会使用该参数传入的颜色填充透明背景。final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- source → String?
-
自定义背景的本地绝对路径。支持 PNG、JPG、MP4、 AVI、 MKV 和 FLV 格式。如果路径无效,SDK 会使用原背景图或 color 指定的纯色背景。 该参数仅在自定义背景图类型为 backgroundImg 或 backgroundVideo 时生效。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited