WatermarkConfig class
用于配置水印信息。
自从 自 v4.6.2 版本新增。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- buffer → WatermarkBuffer?
-
水印的缓冲区。详见 WatermarkBuffer 。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
水印的唯一标识符,建议使用 UUID。
final
- imageUrl → String?
-
水印图像文件的 URL,默认值为 NULL 。
final
- literal → WatermarkLiteral?
-
水印的文本内容。 仅支持在 Linux 平台使用。
final
- options → WatermarkOptions?
-
水印的配置选项。详见 WatermarkOptions 。
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → WatermarkTimestamp?
-
水印的时间戳。 仅支持在 Linux 平台使用。
final
- type → WatermarkSourceType?
-
水印类型,详见 WatermarkSourceType 。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited