WatermarkTimestamp class
用于配置时间戳水印。
自从 自 v4.6.2 版本新增。 仅适用于 Linux 平台。
- Annotations
-
- @JsonSerializable.new(explicitToJson: true, includeIfNull: false)
Properties
- fontFilePath → String?
-
时间戳字体文件的路径。默认值为 NULL 。字体文件需为 .ttf 格式。如果未设置,SDK 会使用系统默认字体(如果可用)。 如果异步使用,请将路径复制到不会被释放的内存中。
final
- fontSize → int?
-
时间戳字体的大小。默认值为 10。
final
- format → String?
-
时间戳的格式。默认值为 %F %X 。格式遵循 C 标准库函数 strftime 的规范,详见 strftime 。 如果异步使用,请将格式字符串复制到不会被释放的内存中。
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- strokeWidth → int?
-
时间戳描边的宽度。默认值为 1。
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited